tinyMCE.addI18n('hu.template_dlg',{
title:"Sablon beilleszt\u00E9se",
label:"Sablon",
desc_label:"Le\u00EDr\u00E1s",
desc:"Sablon beilleszt\u00E9se",
select:"Sablon v\u00E1laszt\u00E1s",
preview:"El\u0151n\u00E9zet",
warning:"Figyelem: Egy m\u00E1r alkalmazott sablon friss\u00EDt\u00E9se m\u00E1sikkal adatveszt\u00E9ssel j\u00E1rhat.",
mdate_format:"%Y.%m.%d. %H:%M:%S",
cdate_format:"%Y.%m.%d. %H:%M:%S",
months_long:"Janu\u00E1r,Febru\u00E1r,M\u00E1rcius,\u00C1prilis,M\u00E1jus,J\u00FAnius,J\u00FAlius,Augusztus,Szeptember,Oktober,November,December",
months_short:"Jan,Feb,M\u00E1r,\u00C1pr,M\u00E1j,J\u00FAn,J\u00FAl,Aug,Szep,Oct,Nov,Dec",
day_long:"Vas\u00E1rnap,H\u00E9tf\u0151,Kedd,Szerda,Cs\u00FCt\u00F6rt\u00F6k,P\u00E9ntek,Szombat,Vas\u00E1rnap",
day_short:"V,H,K,Sze,Cs,P,Szo,V"
});