tinyMCE.addI18n('ja.fullpage_dlg',{
title:"\u30DA\u30FC\u30B8\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
meta_tab:"\u4E00\u822C",
appearance_tab:"\u8868\u793A",
advanced_tab:"\u9AD8\u5EA6",
meta_props:"\u30E1\u30BF\u60C5\u5831",
langprops:"\u8A00\u8A9E\u3068\u30A8\u30F3\u30B3\u30FC\u30C7\u30A3\u30F3\u30B0",
meta_title:"Title",
meta_keywords:"Keywords",
meta_description:"Description",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
langdir:"\u6587\u5B57\u65B9\u5411",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
xml_pi:"XML\u5BA3\u8A00",
encoding:"\u6587\u5B57\u30A8\u30F3\u30B3\u30FC\u30C7\u30A3\u30F3\u30B0",
appearance_bgprops:"\u80CC\u666F\u8A2D\u5B9A",
appearance_marginprops:"Body\u30DE\u30FC\u30B8\u30F3",
appearance_linkprops:"\u30EA\u30F3\u30AF\u8272",
appearance_textprops:"\u30C6\u30AD\u30B9\u30C8\u8A2D\u5B9A",
bgcolor:"\u80CC\u666F\u8272",
bgimage:"\u80CC\u666F\u753B\u50CF",
left_margin:"\u5DE6\u4F59\u767D",
right_margin:"\u53F3\u4F59\u767D",
top_margin:"\u4E0A\u4F59\u767D",
bottom_margin:"\u4E0B\u4F59\u767D",
text_color:"\u6587\u5B57\u8272",
font_size:"\u6587\u5B57\u30B5\u30A4\u30BA",
font_face:"\u30D5\u30A9\u30F3\u30C8",
link_color:"\u30EA\u30F3\u30AF\u8272",
hover_color:"\u30EA\u30F3\u30AF\u8272(hover)",
visited_color:"\u30EA\u30F3\u30AF\u8272(visited)",
active_color:"\u30EA\u30F3\u30AF\u8272(active)",
textcolor:"\u8272",
fontsize:"\u6587\u5B57\u30B5\u30A4\u30BA",
fontface:"\u30D5\u30A9\u30F3\u30C8",
meta_index_follow:"\u5168\u3066\u8A31\u53EF",
meta_index_nofollow:"\u5F53\u30DA\u30FC\u30B8\u3092\u8A31\u53EF\u3057\u30EA\u30F3\u30AF\u5148\u3092\u7981\u6B62",
meta_noindex_follow:"\u5F53\u30DA\u30FC\u30B8\u3092\u7981\u6B62\u3057\u30EA\u30F3\u30AF\u5148\u3092\u8A31\u53EF",
meta_noindex_nofollow:"\u5168\u3066\u7981\u6B62",
appearance_style:"\u30B9\u30BF\u30A4\u30EB\u30B7\u30FC\u30C8\u8A2D\u5B9A",
stylesheet:"\u30B9\u30BF\u30A4\u30EB\u30B7\u30FC\u30C8",
style:"\u30B9\u30BF\u30A4\u30EB",
author:"\u7B46\u8005",
copyright:"Copyright",
add:"\u8981\u7D20\u8FFD\u52A0",
remove:"\u9078\u629E\u8981\u7D20\u3092\u524A\u9664",
moveup:"\u9078\u629E\u8981\u7D20\u3092\u4E0A\u3078\u79FB\u52D5",
movedown:"\u9078\u629E\u8981\u7D20\u3092\u4E0B\u3078\u79FB\u52D5",
head_elements:"Head elements",
info:"Information",
add_title:"Title element",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Style element",
add_link:"Link element",
add_base:"Base element",
add_comment:"Comment node",
title_element:"Title element",
script_element:"Script element",
style_element:"Style element",
base_element:"Base element",
link_element:"Link element",
meta_element:"Meta element",
comment_element:"Comment",
src:"Src",
language:"Language",
href:"Href",
target:"Target",
type:"Type",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"Properties",
name:"Name",
value:"Value",
content:"Content",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"General",
advanced_props:"Advanced"
});