tinyMCE.addI18n({nn:{
common:{
edit_confirm:"Vil du benytte WYSIWYG editoren for dette tekstfelt?",
apply:"Bruk",
insert:"Sett inn",
update:"Oppdater",
cancel:"Avbryt",
close:"Lukk",
browse:"Bla gjennom",
class_name:"Stil",
not_set:"-- Ikkje satt --",
clipboard_msg:"Kopier/Klipp ut/Lim inn er ikkje tilgjengelig i Mozilla/Firefox. Vil du ha meir informasjon om dette?",
clipboard_no_support:"For tiden ikkje st\u00F8ttet av din nettleser, benytt tastatursnarveier i stedet.",
popup_blocked:"Ein popup-blokker har sperret eit vindu med viktig funksjonalitet, for \u00E5 benytte deg av denne funksjonaliteten m\u00E5 du deaktivere popup-blokkeren for dette nettstedet.",
invalid_data:"Feil: Ugyldige, verdier merket med r\u00F8dt, er angitt",
more_colors:"Flere farger"
},
contextmenu:{
align:"Justering",
left:"Venstre",
center:"Sentrert",
right:"H\u00F8yre",
full:"Full"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Sett inn dato",
inserttime_desc:"Sett inn tidspunkt",
months_long:"januar,februar,mars,april,mai,juni,juli,august,september,oktober,november,desember",
months_short:"jan,feb,mar,apr,mai,jun,jul,aug,sep,oct,nov,des",
day_long:"s\u00F8ndag,mandag,tirsdag,onsdag,torsdag,fredag,l\u00F8rdag,s\u00F8ndag",
day_short:"s\u00F8n,man,tir,ons,tor,fre,l\u00F8r,s\u00F8n"
},
print:{
print_desc:"Utskrift"
},
preview:{
preview_desc:"Forh\u00E5ndsvis"
},
directionality:{
ltr_desc:"Retning venstre mot h\u00F8yre",
rtl_desc:"Retning h\u00F8yre mot venstre"
},
layer:{
insertlayer_desc:"Opprett nytt 'layer'",
forward_desc:"Flytt forover",
backward_desc:"Flytt bakover",
absolute_desc:"P\u00E5/av absolutt posisjonering",
content:"Nytt 'layer'..."
},
save:{
save_desc:"Lagre",
cancel_desc:"Kanseller alle endringer"
},
nonbreaking:{
nonbreaking_desc:"Sett inn 'non-breaking' blank karakter"
},
iespell:{
iespell_desc:"Kj\u00F8r stavekontroll",
download:"ieSpell ikkje funnet. \u00D8nsker du \u00E5 installere ieSpell n\u00E5?"
},
advhr:{
advhr_desc:"Horisontal 'ruler'"
},
emotions:{
emotions_desc:"F\u00F8lelser"
},
searchreplace:{
search_desc:"S\u00F8k",
replace_desc:"S\u00F8k/Erstatt"
},
advimage:{
image_desc:"Opprett/endre bilde"
},
advlink:{
link_desc:"Opprett/endre lenke"
},
xhtmlxtras:{
cite_desc:"Henvisning",
abbr_desc:"Forkortelse",
acronym_desc:"Bokstavord",
del_desc:"Fjerning",
ins_desc:"Innsetting",
attribs_desc:"Opprett/Endre Egenskaper"
},
style:{
desc:"Edit CSS Style"
},
paste:{
paste_text_desc:"Lim inn som 'ren' tekst",
paste_word_desc:"Lim inn fra Office",
selectall_desc:"Velg alt"
},
paste_dlg:{
text_title:"Bruk CTRL+V p\u00E5 tastaturet ditt for \u00E5 lime inn i dette vinduet.",
text_linebreaks:"Behold linjebrudd",
word_title:"Bruk CTRL+V p\u00E5 tastaturet ditt for \u00E5 lime inn i dette vinduet."
},
table:{
desc:"Sett inn ein ny tabell",
row_before_desc:"Sett inn rad foran",
row_after_desc:"Sett inn rad etter",
delete_row_desc:"Fjern rad",
col_before_desc:"Sett inn kolonne foran",
col_after_desc:"Sett inn kolonne etter",
delete_col_desc:"Fjern kolonne",
split_cells_desc:"Splitt tabell celler",
merge_cells_desc:"Sl\u00E5 sammen tabell celler",
row_desc:"Tabell rad egenskaper",
cell_desc:"Tabell celle egenskaper",
props_desc:"Tabell egenskaper",
paste_row_before_desc:"Lim inn tabell rad foran",
paste_row_after_desc:"Lim inn tabell rad etter",
cut_row_desc:"Klipp ut tabell rad",
copy_row_desc:"Kopier tabell rad",
del:"Fjern tabell",
row:"Rad",
col:"Kolonne",
cell:"Celle"
},
autosave:{
unload_msg:"Endringene du gjorde kommer du til \u00E5 miste om du velger \u00E5 forlate denne siden."
},
fullscreen:{
desc:"Sl\u00E5 av/p\u00E5 fullskjerm"
},
media:{
desc:"Opprett / endre innsatt media",
edit:"Endre innsatt media"
},
fullpage:{
desc:"Dokument egenskaper"
},
template:{
desc:"Sett inn ein forh\u00E5ndsdefinert mal"
},
visualchars:{
desc:"Visuell kontroll karakterer av/p\u00E5."
},
spellchecker:{
desc:"Stavekontroll",
menu:"Oppsett stavekontroll",
ignore_word:"Ignorer ordet",
ignore_words:"Ignorer alt",
langs:"Spr\u00E5k",
wait:"Vennligst vent...",
sug:"Forslag",
no_sug:"Ingen forslag",
no_mpell:"Ingen stavefeil funnet."
},
pagebreak:{
desc:"Insert page break."
}}});