tinyMCE.addI18n('ar.emotions_dlg',{
title:"\u0625\u062F\u0631\u0627\u062C \u0627\u0628\u062A\u0633\u0627\u0645\u0629",
desc:"\u0627\u0644\u0625\u0628\u062A\u0633\u0627\u0645\u0627\u062A",
cool:"Cool",
cry:"Cry",
embarassed:"Embarassed",
foot_in_mouth:"Foot in mouth",
frown:"Frown",
innocent:"Innocent",
kiss:"Kiss",
laughing:"Laughing",
money_mouth:"Money mouth",
sealed:"Sealed",
smile:"Smile",
surprised:"Surprised",
tongue_out:"Tongue out",
undecided:"Undecided",
wink:"Wink",
yell:"Yell"
});