tinyMCE.addI18n('es.searchreplace_dlg',{
searchnext_desc:"Buscar de nuevo",
notfound:"La busqueda se ha completado. El texto buscado no fue encontrado.",
search_title:"Buscar",
replace_title:"Buscar/Reemplazar",
allreplaced:"Se ha reemplazado el texto donde aparecia.",
findwhat:"Que buscar",
replacewith:"Reemplazar por",
direction:"Direccion",
up:"Arriba",
down:"Abajo",
mcase:"Minus./Mayus.",
findnext:"Buscar proximo",
replace:"Reemplazar",
replaceall:"Reemplazar todo"
});