tinyMCE.addI18n('nn.advlink_dlg',{
title:"Opprett/endre lenke",
url:"Lenke URL",
target:"M\u00E5l",
titlefield:"Tittel",
is_email:"URL'en du oppga synes \u00E5 v\u00E6re ein email adresse, \u00F8nsker du \u00E5 legge til den n\u00F8dvendige mailto: prefix?",
is_external:"URL'en du oppga synes \u00E5 v\u00E6re ein ekstern lenke, \u00F8nsker du \u00E5 legge til den n\u00F8dvendige http:// prefix?",
list:"Lenke liste",
general_tab:"Generelt",
popup_tab:"Popup",
events_tab:"Hendelse",
advanced_tab:"Avansert",
general_props:"Generelle egenskaper",
popup_props:"Popup egenskaper",
event_props:"Hendelser",
advanced_props:"Avanserte egenskaper",
popup_opts:"Opsjoner",
anchor_names:"Anker",
target_same:"\u00C5pne i dette vindu / frame",
target_parent:"\u00C5pne i foreldrevindu / frame",
target_top:"\u00C5pne i topp frame (utbytter alle 'frames')",
target_blank:"\u00C5pne i nytt vindu",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"Vinduets navn",
popup_return:"Sett inn 'return false'",
popup_scrollbars:"Vis scrollbars",
popup_statusbar:"Vis status bar",
popup_toolbar:"Vis toolbars",
popup_menubar:"Vis menu bar",
popup_location:"Vis location bar",
popup_resizable:"Gjer vinduet skalerbart",
popup_dependent:"Avhengig vindu (kun Mozilla/Firefox)",
popup_size:"St\u00F8rrelse",
popup_position:"Posisjon (X/Y)",
id:"Id",
style:"Stil",
classes:"CSS klasser",
target_name:"M\u00E5l navn",
langdir:"Spr\u00E5k retning",
target_langcode:"M\u00E5l spr\u00E5k",
langcode:"Spr\u00E5k kode",
encoding:"Tegn konvertering",
mime:"M\u00E5l MIME type",
rel:"Relasjon side til m\u00E5l",
rev:"Relasjon m\u00E5l til side",
tabindex:"Tabindex",
accesskey:"Accesskey",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre mot venstre",
link_list:"Lenke liste"
});