tinyMCE.addI18n('nn.style_dlg',{
title:"Edit CSS Style",
apply:"Bruk",
text_tab:"Tekst",
background_tab:"Bakgrunn",
block_tab:"Blokk",
box_tab:"Boks",
border_tab:"Ramme",
list_tab:"Liste",
positioning_tab:"Posisjonering",
text_props:"Tekst",
text_font:"Font",
text_size:"St\u00F8rrelse",
text_weight:"Vekt",
text_style:"Stil",
text_variant:"Variant",
text_lineheight:"Linje h\u00F8yde",
text_case:"Case",
text_color:"Farge",
text_decoration:"Dekorasjon",
text_overline:"overstrekning",
text_underline:"understrekning",
text_striketrough:"gjennomstrekning",
text_blink:"blink",
text_none:"ingen",
background_color:"Bakgrunn farge",
background_image:"Bakgrunn bilde",
background_repeat:"Gjenta",
background_attachment:"Vedlegg",
background_hpos:"Horisontal posisjon",
background_vpos:"Vertikal posisjon",
block_wordspacing:"Ord mellomrom",
block_letterspacing:"Bokstav mellomrom",
block_vertical_alignment:"Vertikal justering",
block_text_align:"Tekst justering",
block_text_indent:"Tekst innrykk",
block_whitespace:"Whitespace",
block_display:"Vis",
box_width:"Bredde",
box_height:"H\u00F8yde",
box_float:"Flytende",
box_clear:"Fjern",
padding:"Fylling",
same:"Samme for alle",
top:"Topp",
right:"H\u00F8yre",
bottom:"Bunnen",
left:"Venstre",
margin:"Marg",
style:"Stil",
width:"Bredde",
height:"H\u00F8yde",
color:"Farge",
list_type:"Type",
bullet_image:"Bullet bilde",
position:"Posisjon",
positioning_type:"Type",
visibility:"Visibility",
zindex:"Z-index",
overflow:"Overflow",
placement:"Plasering",
clip:"Clip"
});