tinyMCE.addI18n('nn.paste_dlg',{
text_title:"Bruk CTRL+V p\u00E5 tastaturet ditt for \u00E5 lime inn i dette vinduet.",
text_linebreaks:"Behold linjebrudd",
word_title:"Bruk CTRL+V p\u00E5 tastaturet ditt for \u00E5 lime inn i dette vinduet."
});