tinyMCE.addI18n('fi.media_dlg',{
title:"Lis\u00E4\u00E4/muokkaa upotettua mediaa",
general:"Yleiset",
advanced:"Edistyneet",
file:"Tiedosto/URL",
list:"Lista",
size:"Mitat",
preview:"Esikatselu",
constrain_proportions:"S\u00E4ilyt\u00E4 mittasuhteet",
type:"Tyyppi",
id:"Id",
name:"Name",
class_name:"Luokka",
vspace:"Pystytason tila",
hspace:"Vaakatason tila",
play:"Automaattinen toisto",
loop:"Silmukka",
menu:"N\u00E4yt\u00E4 valikko",
quality:"Laatu",
scale:"Skaala",
align:"Tasaus",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Tausta",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"V\u00E4limuisti",
hidden:"Piilotettu",
controller:"Ohjain",
kioskmode:"Kioski-tila",
playeveryframe:"Toista jokainen ruutu",
targetcache:"Kohteen v\u00E4limuisti",
correction:"Ei korjausta",
enablejavascript:"Salli JavaScript",
starttime:"Aloitus aika",
endtime:"Lopetus aika",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Kohde",
volume:"\u00C4\u00E4nen voimakkuus",
autostart:"Automaattinen aloitus",
enabled:"P\u00E4\u00E4ll\u00E4",
fullscreen:"Kokoruutu",
invokeurls:"Invoke URLs",
mute:"Mute",
stretchtofit:"Venyt\u00E4 sopimaan",
windowlessvideo:"Ikkunaton video",
balance:"Tasapaino",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Current position",
defaultframe:"Default frame",
playcount:"Play count",
rate:"Rate",
uimode:"UI Mode",
flash_options:"Flash options",
qt_options:"Quicktime options",
wmp_options:"Windows media player options",
rmp_options:"Real media player options",
shockwave_options:"Shockwave options",
autogotourl:"Auto goto URL",
center:"Center",
imagestatus:"Image status",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Console",
numloop:"Num loops",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"Sound",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"Top",
align_right:"Right",
align_bottom:"Bottom",
align_left:"Left",
align_center:"Center",
align_top_left:"Top left",
align_top_right:"Top right",
align_bottom_left:"Bottom left",
align_bottom_right:"Bottom right",
flv_options:"Flash video options",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"Start image",
flv_starttime:"Start time",
flv_defaultvolume:"Default volumne",
flv_hiddengui:"Hidden GUI",
flv_autostart:"Auto start",
flv_loop:"Loop",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});