tinyMCE.addI18n('fa.fullpage_dlg',{
title:"Document properties",
meta_tab:"\u0639\u0645\u0648\u0645\u06CC",
appearance_tab:"Appearance",
advanced_tab:"\u067E\u06CC\u0634\u0631\u0641\u062A\u0647",
meta_props:"Meta information",
langprops:"Language and encoding",
meta_title:"\u0639\u0646\u0648\u0627\u0646",
meta_keywords:"\u06A9\u0644\u0645\u0627\u062A \u06A9\u0644\u06CC\u062F\u06CC",
meta_description:"\u062A\u0648\u0636\u06CC\u062D\u0627\u062A",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"\u06A9\u062F \u0632\u0628\u0627\u0646",
langdir:"\u062C\u0647\u062A \u0632\u0628\u0627\u0646",
ltr:"\u0686\u067E \u0628\u0647 \u0631\u0627\u0633\u062A",
rtl:"\u0631\u0627\u0633\u062A \u0628\u0647 \u0686\u067E",
xml_pi:"XML \u062A\u0639\u0627\u0631\u06CC\u0641",
encoding:"Character encoding",
appearance_bgprops:"\u0645\u0634\u062E\u0635\u0627\u062A \u067E\u0633 \u0632\u0645\u06CC\u0646\u0647",
appearance_marginprops:"Body margins",
appearance_linkprops:"Link colors",
appearance_textprops:"\u0645\u0634\u062E\u0635\u0627\u062A \u0645\u062A\u0646",
bgcolor:"\u0631\u0646\u06AF \u067E\u0633 \u0632\u0645\u06CC\u0646\u0647",
bgimage:"\u062A\u0635\u0648\u06CC\u0631 \u067E\u0633 \u0632\u0645\u06CC\u0646\u0647",
left_margin:"Left margin",
right_margin:"Right margin",
top_margin:"Top margin",
bottom_margin:"Bottom margin",
text_color:"\u0631\u0646\u06AF \u0645\u062A\u0646",
font_size:"\u0627\u0646\u062F\u0627\u0632\u0647 \u0642\u0644\u0645",
font_face:"Font face",
link_color:"\u0631\u0646\u06AF \u0644\u06CC\u0646\u06A9",
hover_color:"Hover color",
visited_color:"Visited color",
active_color:"Active color",
textcolor:"\u0631\u0646\u06AF",
fontsize:"\u0627\u0646\u062F\u0627\u0632\u0647 \u0642\u0644\u0645",
fontface:"\u062E\u0627\u0646\u0648\u0627\u062F\u0647 \u0642\u0644\u0645",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"Stylesheet and style properties",
stylesheet:"Stylesheet",
style:"\u0633\u0628\u06A9",
author:"Author",
copyright:"\u062D\u0642 \u0646\u0634\u0631",
add:"\u062F\u0631\u062C \u0639\u0646\u0635\u0631 \u062C\u062F\u06CC\u062F",
remove:"\u062D\u0630\u0641 \u0639\u0646\u0635\u0631 \u0627\u0646\u062A\u062E\u0627\u0628 \u0634\u062F\u0647",
moveup:"Move selected element up",
movedown:"Move selected element down",
head_elements:"Head elements",
info:"\u0627\u0637\u0644\u0627\u0639\u0627\u062A",
add_title:"\u0639\u0646\u0648\u0627\u0646 \u0639\u0646\u0635\u0631",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Style element",
add_link:"Link element",
add_base:"Base element",
add_comment:"Comment node",
title_element:"Title element",
script_element:"Script element",
style_element:"Style element",
base_element:"Base element",
link_element:"Link element",
meta_element:"Meta element",
comment_element:"Comment",
src:"Src",
language:"\u0632\u0628\u0627\u0646",
href:"Href",
target:"\u0647\u062F\u0641",
type:"\u0646\u0648\u0639",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"\u0645\u0634\u062E\u0635\u0627\u062A",
name:"\u0646\u0627\u0645",
value:"Value",
content:"Content",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"\u0639\u0645\u0648\u0645\u06CC",
advanced_props:"\u067E\u06CC\u0634\u0631\u0641\u062A\u0647"
});