tinyMCE.addI18n('es.template_dlg',{
title:"Plantillas",
label:"Plantilla",
desc_label:"Descripcion",
desc:"Insertar contenido de plantilla predefinida",
select:"Seleccionar plantilla",
preview:"Vista previa",
warning:"Cuidado: Actualizando una plantilla con otra puede causar perdida de datos.",
mdate_format:"%d-%m-%Y %H:%M:%S",
cdate_format:"%d-%m-%Y %H:%M:%S",
months_long:"Enero,Febrero,Marzo,Abril,Mayo,Junio,Julio,Agosto,Septiembre,Octubre,Noviembre,Diciembre",
months_short:"Ene,Feb,Mar,Abr,May,Jun,Jul,Ago,Sep,Oct,Nov,Dic",
day_long:"Domingo,Lunes,Martes,Miercoles,Jueves,Viernes,Sabado,Domingo",
day_short:"Dom,Lun,Mar,Mie,Jue,Vie,Sab,Dom"
});