tinyMCE.addI18n('ar.style_dlg',{
title:"Edit CSS Style",
apply:"Apply",
text_tab:"Text",
background_tab:"Background",
block_tab:"Block",
box_tab:"Box",
border_tab:"\u0627\u0644\u062D\u062F\u0648\u062F",
list_tab:"List",
positioning_tab:"Positioning",
text_props:"Text",
text_font:"Font",
text_size:"Size",
text_weight:"Weight",
text_style:"Style",
text_variant:"Variant",
text_lineheight:"Line height",
text_case:"Case",
text_color:"\u0627\u0644\u0644\u0648\u0646",
text_decoration:"Decoration",
text_overline:"overline",
text_underline:"underline",
text_striketrough:"strikethrough",
text_blink:"blink",
text_none:"none",
background_color:"\u0644\u0648\u0646 \u0627\u0644\u062E\u0644\u0641\u064A\u0629",
background_image:"\u0635\u0648\u0631\u0629 \u0627\u0644\u062E\u0644\u0641\u064A\u0629",
background_repeat:"Repeat",
background_attachment:"Attachment",
background_hpos:"Horizontal position",
background_vpos:"Vertical position",
block_wordspacing:"Word spacing",
block_letterspacing:"Letter spacing",
block_vertical_alignment:"Vertical alignment",
block_text_align:"Text align",
block_text_indent:"Text indent",
block_whitespace:"Whitespace",
block_display:"\u0627\u0644\u0639\u0631\u0636",
box_width:"\u0627\u0644\u0639\u0631\u0636",
box_height:"\u0627\u0644\u0625\u0631\u062A\u0641\u0627\u0639",
box_float:"Float",
box_clear:"Clear",
padding:"Padding",
same:"Same for all",
top:"\u0623\u0639\u0644\u0649",
right:"\u064A\u0645\u064A\u0646",
bottom:"\u0623\u0633\u0641\u0644",
left:"\u064A\u0633\u0627\u0631",
margin:"Margin",
style:"Style",
width:"\u0627\u0644\u0639\u0631\u0636",
height:"\u0627\u0644\u0625\u0631\u062A\u0641\u0627\u0639",
color:"\u0627\u0644\u0644\u0648\u0646",
list_type:"Type",
bullet_image:"Bullet image",
position:"Position",
positioning_type:"Type",
visibility:"Visibility",
zindex:"Z-index",
overflow:"Overflow",
placement:"Placement",
clip:"Clip"
});