tinyMCE.addI18n('zh.style_dlg',{
title:" \u7DE8\u8F2F CSS \u6A23\u5F0F ",
apply:" \u61C9\u7528 ",
text_tab:" \u6587\u672C ",
background_tab:" \u80CC\u666F ",
block_tab:" \u5340\u584A ",
box_tab:" \u76D2\u6A21\u578B ",
border_tab:" \u908A\u6846 ",
list_tab:" \u5217\u8868 ",
positioning_tab:" \u4F4D\u7F6E ",
text_props:" \u6587\u5B57 ",
text_font:" \u5B57\u578B ",
text_size:" \u5927\u5C0F ",
text_weight:" \u7C97\u7D30 ",
text_style:" \u6A23\u5F0F ",
text_variant:" \u8B8A\u9AD4 ",
text_lineheight:" \u884C\u9AD8 ",
text_case:" \u5927\u5C0F\u5BEB ",
text_color:" \u984F\u8272 ",
text_decoration:" \u4FEE\u98FE ",
text_overline:" \u4E0A\u5283\u7DDA ",
text_underline:" \u5E95\u7DDA ",
text_striketrough:" \u522A\u9664\u7DDA ",
text_blink:" \u9583\u720D ",
text_none:" \u7121 ",
background_color:" \u80CC\u666F\u984F\u8272 ",
background_image:" \u80CC\u666F\u5716\u50CF ",
background_repeat:" \u91CD\u8907 ",
background_attachment:" \u798F\u5EFA ",
background_hpos:" \u6C34\u5E73\u4F4D\u7F6E ",
background_vpos:" \u5782\u76F4\u4F4D\u7F6E ",
block_wordspacing:" \u55AE\u8A5E\u9593\u8DDD ",
block_letterspacing:" \u5B57\u7B26\u9593\u8DDD ",
block_vertical_alignment:" \u5782\u76F4\u5C0D\u9F4A ",
block_text_align:" \u6587\u672C\u5C0D\u9F4A ",
block_text_indent:" \u6587\u5B57\u7E2E\u6392 ",
block_whitespace:" \u7A7A\u683C ",
block_display:" \u986F\u793A ",
box_width:" \u5BEC ",
box_height:" \u9AD8 ",
box_float:" \u6D6E\u52D5 ",
box_clear:" \u6E05\u9664 ",
padding:" \u586B\u5145 ",
same:" \u5168\u90E8\u76F8\u540C ",
top:" \u4E0A ",
right:" \u53F3 ",
bottom:" \u4E0B ",
left:" \u5DE6 ",
margin:" \u908A\u754C ",
style:" \u6A23\u5F0F ",
width:" \u5BEC\u5EA6 ",
height:" \u9AD8\u5EA6 ",
color:" \u984F\u8272 ",
list_type:" \u985E\u578B ",
bullet_image:" \u9805\u76EE\u7B26\u865F\u5716\u50CF ",
position:" \u4F4D\u7F6E ",
positioning_type:" \u985E\u578B ",
visibility:" \u986F\u793A ",
zindex:"Z \u8EF8 ",
overflow:" \u6EA2\u51FA ",
placement:" \u5B9A\u4F4D ",
clip:" \u526A\u8F2F "
});