tinyMCE.addI18n('nn.advanced',{
style_select:"Stiler",
font_size:"Skriftst\u00F8rrelse",
fontdefault:"Skriftfamilie",
block:"Format",
paragraph:"Avsnitt",
div:"Div",
address:"Adresse",
pre:"Pre-formatert",
h1:"Overskrift 1",
h2:"Overskrift 2",
h3:"Overskrift 3",
h4:"Overskrift 4",
h5:"Overskrift 5",
h6:"Overskrift 6",
blockquote:"Sitatinnrykk",
code:"Kode",
samp:"Kodeeksempel",
dt:"Definisjonsuttrykk",
dd:"Definisjonsbeskrivelse",
bold_desc:"Feit (Ctrl+B)",
italic_desc:"Kursiv (Ctrl+I)",
underline_desc:"Understreket (Ctrl+U)",
striketrough_desc:"Gjennomstreket",
justifyleft_desc:"Venstrestilt",
justifycenter_desc:"Midtstilt",
justifyright_desc:"H\u00F8yrestilt",
justifyfull_desc:"Blokkjustering",
bullist_desc:"Punktliste",
numlist_desc:"Nummerliste",
outdent_desc:"Reduser innrykk",
indent_desc:"Auk innrykk",
undo_desc:"Angre (Ctrl+Z)",
redo_desc:"Gjer om (Ctrl+Y)",
link_desc:"Opprett/endre lenke",
unlink_desc:"Fjern lenke",
image_desc:"Opprett/endre bilde",
cleanup_desc:"Rens uryddig kode",
code_desc:"Redigere HTML-koden",
sub_desc:"Senket skrift",
sup_desc:"Hevet skrift",
hr_desc:"Sett inn horisontal linje",
removeformat_desc:"Fjern formatering",
custom1_desc:"Din spesialfunksjons beskrivelse her",
forecolor_desc:"Velg skriftfarge",
backcolor_desc:"Velg bakgrunnsfarge",
charmap_desc:"Sett inn spesialtegn",
visualaid_desc:"Sl\u00E5 av/p\u00E5 usynlige elementer",
anchor_desc:"Opprette/endre anker",
cut_desc:"Klipp ut",
copy_desc:"Kopier",
paste_desc:"Lim inn",
image_props_desc:"Bildeegenskaper",
newdocument_desc:"Nytt dokument",
help_desc:"Hjelp",
blockquote_desc:"Sitatinnrykk",
clipboard_msg:"Kopier/Klipp ut/Lim inn er ikkje tilgjengelig i Mozilla/Firefox.\nVil du ha meir informasjon om dette?",
path:"S\u00F8kesti",
newdocument:"Er du sikker p\u00E5 at du vil t\u00F8mme hele redigeringsomr\u00E5det?",
toolbar_focus:"Hopp til verkt\u00F8ylinje - Alt+Q, hopp til teksbehandler - Alt+Z , hopp til elementsti - Alt+X",
more_colors:"Flere farger"
});