tinyMCE.addI18n('pt.table_dlg',{
general_tab:"Geral",
advanced_tab:"Avan\u00E7ado",
general_props:"Propriedades Gerais",
advanced_props:"Propriedades Avan\u00E7adas",
rowtype:"Row in table part",
title:"Inserir/Modificar tabela",
width:"Largura",
height:"Altura",
cols:"Cols",
rows:"Rows",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Borda",
align:"Alinhamento",
align_default:"Padr\u00E3o",
align_left:"Esquerda",
align_right:"Direita",
align_middle:"Centro",
row_title:"Propriedades de Fileiras",
cell_title:"Propriedades de C\u00E9lulas",
cell_type:"Tipo de C\u00E9lula",
valign:"Alinhamento Vertical",
align_top:"Topo",
align_bottom:"Embaixo",
bordercolor:"Cor da Borda",
bgcolor:"Cor de Fundo",
merge_cells_title:"Unir c\u00E9lulas",
id:"Id",
style:"Estilo",
langdir:"Dire\u00E7\u00E3o do Texto",
langcode:"C\u00F3digo da Linguagem",
mime:"MIME alvo",
ltr:"Esquerda para Direita",
rtl:"Direita para Esquerda",
bgimage:"Imagem de fundo",
summary:"Sum\u00E1rio",
td:"Dados",
th:"Campo",
cell_cell:"Atualizar esta c\u00E9lula",
cell_row:"Atualizar todas as c\u00E9lulas na fileira",
cell_all:"Atualizar todas as c\u00E9lulas na tabela",
row_row:"Atualizar esta fileira",
row_odd:"Atualizar fileiras \u00EDmpares",
row_even:"Atualizar fileiras pares",
row_all:"Atualizar todas fileiras",
thead:"Topo da Tabela",
tbody:"Corpo da Tabela",
tfoot:"Rodap\u00E9 da Tabela",
scope:"Alcance",
rowgroup:"Grupo Fileiras",
colgroup:"Grupo Colunas",
col_limit:"Voc\u00EA excedeu o n\u00FAmero m\u00E1ximo de colunas de {$cols}.",
row_limit:"Voc\u00EA excedeu o n\u00FAmero m\u00E1ximo de fileiras de {$rows}.",
cell_limit:"Voc\u00EA excedeu o n\u00FAmero m\u00E1ximo de c\u00E9lulas de {$cells}.",
missing_scope:"Tem certeza de que quer continuar sem especificar um alcance para esta c\u00E9lula? (Isso poder\u00E1 causar dificuldades a usu\u00E1rios deficientes)",
caption:"T\u00EDtulo da Tabela",
frame:"Frame",
frame_none:"nenhum",
frame_groups:"grupos",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"todos",
rules:"Rules",
rules_void:"void",
rules_above:"acima",
rules_below:"abaixo",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"borda"
});