tinyMCE.addI18n('nn.fullpage_dlg',{
title:"Dokument egenskaper",
meta_tab:"Generelt",
appearance_tab:"Utseende",
advanced_tab:"Avansert",
meta_props:"Meta informasjon",
langprops:"Spr\u00E5k og koding",
meta_title:"Tittel",
meta_keywords:"Keywords",
meta_description:"Beskrivelse",
meta_robots:"Roboter",
doctypes:"Doctype",
langcode:"Spr\u00E5k kode",
langdir:"Spr\u00E5k retning",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre mot venstre",
xml_pi:"XML deklarasjon",
encoding:"Tegn konvertering",
appearance_bgprops:"Bakgrunn egenskaper",
appearance_marginprops:"Body marg",
appearance_linkprops:"Lenke farger",
appearance_textprops:"Tekst egenskaper",
bgcolor:"Bakgrunn farge",
bgimage:"Bakgrunn bilde",
left_margin:"Venstre marg",
right_margin:"H\u00F8yre marg",
top_margin:"Topp marg",
bottom_margin:"Bunn marg",
text_color:"Tekst farge",
font_size:"Font st\u00F8rrelse",
font_face:"Font face",
link_color:"Lenke farge",
hover_color:"Musover farge",
visited_color:"Bes\u00F8kt farge",
active_color:"Aktive farge",
textcolor:"Farge",
fontsize:"Font st\u00F8rrelse",
fontface:"Font famile",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"Stylesheet and style properties",
stylesheet:"Stylesheet",
style:"Stil",
author:"Forfatter",
copyright:"Copyright",
add:"Add new element",
remove:"Fjern markert element",
moveup:"Flytt markert element opp",
movedown:"Flytt markert element ned",
head_elements:"Head element",
info:"Informasjon",
add_title:"Tittel element",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Stil element",
add_link:"Lenke element",
add_base:"Base element",
add_comment:"Kommentar node",
title_element:"Tittel element",
script_element:"Script element",
style_element:"Stil element",
base_element:"Base element",
link_element:"Lenke element",
meta_element:"Meta element",
comment_element:"Kommentar",
src:"Src",
language:"Spr\u00E5k",
href:"Href",
target:"Target",
type:"Type",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"Egenskaper",
name:"Navn",
value:"Verdi",
content:"Innhold",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Generelt",
advanced_props:"Avansert"
});