tinyMCE.addI18n('sl.style_dlg',{
title:"Uredi sloge CSS",
apply:"Uporabi",
text_tab:"Besedilo",
background_tab:"Ozadje",
block_tab:"Blok",
box_tab:"Okvir",
border_tab:"Obroba",
list_tab:"Seznam",
positioning_tab:"Polo\u017Eaj",
text_props:"Besedilo",
text_font:"Pisava",
text_size:"Velikost",
text_weight:"Ute\u017E",
text_style:"Slog",
text_variant:"Razli\u010Dica",
text_lineheight:"Vi\u0161ina vrstice",
text_case:"Velikost",
text_color:"Barva",
text_decoration:"Okras",
text_overline:"nad\u010Drtano",
text_underline:"pod\u010Drtano",
text_striketrough:"pre\u010Drtano",
text_blink:"utripajo\u010De",
text_none:"brez",
background_color:"Barva ozadja",
background_image:"Slika ozadja",
background_repeat:"Ponavljaj",
background_attachment:"Priponka",
background_hpos:"Vodoravni polo\u017Eaj",
background_vpos:"Navpi\u010Dni polo\u017Eaj",
block_wordspacing:"Razmik besed",
block_letterspacing:"Razmik znakov",
block_vertical_alignment:"Navpi\u010Dna poravnava",
block_text_align:"Poravnava besedila",
block_text_indent:"Zamik besedila",
block_whitespace:"Beli prostor",
block_display:"Prikaz",
box_width:"\u0160irina",
box_height:"Vi\u0161ina",
box_float:"Plavojo\u010De",
box_clear:"\u010Cisto",
padding:"Podlaganje",
same:"Enako za vse",
top:"Zgoraj",
right:"Desno",
bottom:"Spodaj",
left:"Levo",
margin:"Rob",
style:"Slog",
width:"\u0160irina",
height:"Vi\u0161ina",
color:"Barva",
list_type:"Vrsta",
bullet_image:"Slika alineje",
position:"Polo\u017Eaj",
positioning_type:"Vrsta",
visibility:"Vidnost",
zindex:"Indeks-Z",
overflow:"Prelivanje",
placement:"Polo\u017Eaj",
clip:"Obre\u017Ei"
});