tinyMCE.addI18n('ar.fullpage_dlg',{
title:"\u062E\u0635\u0627\u0626\u0635 \u0627\u0644\u0645\u0633\u062A\u0646\u062F",
meta_tab:"\u0639\u0627\u0645",
appearance_tab:"\u0627\u0644\u0645\u0638\u0647\u0631",
advanced_tab:"\u0645\u062A\u0642\u062F\u0645",
meta_props:"Meta information",
langprops:"\u0627\u0644\u0644\u063A\u0629 \u0648\u0627\u0644\u062A\u0634\u0641\u064A\u0631",
meta_title:"\u0627\u0644\u0639\u0646\u0648\u0627\u0646",
meta_keywords:"\u0643\u0644\u0645\u0627\u062A \u0627\u0644\u0628\u062D\u062B",
meta_description:"\u0627\u0644\u0648\u0635\u0641",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"\u0634\u0641\u0631\u0629 \u0627\u0644\u0644\u063A\u0629",
langdir:"\u0627\u062A\u062C\u0627\u0647 \u0627\u0644\u0644\u063A\u0629",
ltr:"\u064A\u0633\u0627\u0631 to \u064A\u0645\u064A\u0646",
rtl:"\u064A\u0645\u064A\u0646 to \u064A\u0633\u0627\u0631",
xml_pi:"XML declaration",
encoding:"Character encoding",
appearance_bgprops:"Background \u062E\u0635\u0627\u0626\u0635",
appearance_marginprops:"Body margins",
appearance_linkprops:"\u0623\u0644\u0648\u0627\u0646 \u0627\u0644\u0631\u0627\u0628\u0637",
appearance_textprops:"\u062E\u0635\u0627\u0626\u0635 \u0627\u0644\u0646\u0635",
bgcolor:"\u0644\u0648\u0646 \u0627\u0644\u062E\u0644\u0641\u064A\u0629",
bgimage:"\u0635\u0648\u0631\u0629 \u0627\u0644\u062E\u0644\u0641\u064A\u0629",
left_margin:"\u064A\u0633\u0627\u0631 margin",
right_margin:"\u064A\u0645\u064A\u0646 margin",
top_margin:"\u0623\u0639\u0644\u0649 margin",
bottom_margin:"\u0623\u0633\u0641\u0644 margin",
text_color:"Text color",
font_size:"\u062D\u062C\u0645 \u0627\u0644\u062E\u0637",
font_face:"Font face",
link_color:"Link color",
hover_color:"Hover color",
visited_color:"Visited color",
active_color:"Active color",
textcolor:"\u0627\u0644\u0644\u0648\u0646",
fontsize:"\u062D\u062C\u0645 \u0627\u0644\u062E\u0637",
fontface:"\u0646\u0648\u0639 \u0627\u0644\u062E\u0637",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"Stylesheet and style \u062E\u0635\u0627\u0626\u0635",
stylesheet:"Stylesheet",
style:"Style",
author:"\u0627\u0644\u0645\u0624\u0644\u0641",
copyright:"\u062D\u0642\u0648\u0642 \u0627\u0644\u0646\u0633\u062E",
add:"Add new element",
remove:"Remove selected element",
moveup:"Move selected element up",
movedown:"Move selected element down",
head_elements:"Head elements",
info:"Information",
add_title:"Title element",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Style element",
add_link:"Link element",
add_base:"Base element",
add_comment:"Comment node",
title_element:"Title element",
script_element:"Script element",
style_element:"Style element",
base_element:"Base element",
link_element:"Link element",
meta_element:"Meta element",
comment_element:"Comment",
src:"Src",
language:"\u0627\u0644\u0644\u063A\u0629",
href:"Href",
target:"\u0627\u0644\u0645\u0633\u0627\u0631",
type:"Type",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"Properties",
name:"Name",
value:"\u0627\u0644\u0642\u064A\u0645\u0629",
content:"\u0627\u0644\u0645\u062D\u062A\u0648\u0649",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"\u0639\u0627\u0645",
advanced_props:"\u0645\u062A\u0642\u062F\u0645"
});