tinyMCE.addI18n('pt.fullpage_dlg',{
title:"Propriedades do Documento",
meta_tab:"Geral",
appearance_tab:"Apar\u00EAncia",
advanced_tab:"Avan\u00E7ado",
meta_props:"Meta-informa\u00E7\u00E3o",
langprops:"Linguagem e Codifica\u00E7\u00E3o",
meta_title:"T\u00EDtulo",
meta_keywords:"Palavras-Chave",
meta_description:"Descri\u00E7\u00E3o",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"C\u00F3digo de Linguagem",
langdir:"Dire\u00E7\u00E3o do texto",
ltr:"Esquerda para Direita",
rtl:"Direita para Esquerda",
xml_pi:"Declara\u00E7\u00E3o XML",
encoding:"Codifica\u00E7\u00E3o de Caracteres",
appearance_bgprops:"Propriedades do Plano de Fundo",
appearance_marginprops:"Margens (BODY)",
appearance_linkprops:"Cores dos Links",
appearance_textprops:"Propriedades de Texto",
bgcolor:"Cor de Fundo",
bgimage:"Imagem de Fundo",
left_margin:"Margem Esquerda",
right_margin:"Margem Direita",
top_margin:"Margem Topo",
bottom_margin:"Margem Base",
text_color:"Cor do Texto",
font_size:"Tamanho fonte",
font_face:"Fam\u00EDlia fonte",
link_color:"Cores dos Links",
hover_color:"hover",
visited_color:"visited",
active_color:"active",
textcolor:"Cor",
fontsize:"Tamanho fonte",
fontface:"Fam\u00EDlia fonte",
meta_index_follow:"Indexar e seguir os links",
meta_index_nofollow:"Indexar e n\u00E3o seguir os links",
meta_noindex_follow:"Seguir links, mas n\u00E3o indexar",
meta_noindex_nofollow:"N\u00E3o indexar/n\u00E3o seguir links.",
appearance_style:"Propriedades de Folhas de Estilo",
stylesheet:"Folha de Estilo",
style:"Estilo",
author:"Autor",
copyright:"Copyright",
add:"Acrescentar Novo Elemento",
remove:"Remover elemento selecionado",
moveup:"Subir elemento selecionado",
movedown:"Descer elemento selecionado",
head_elements:"Elementos HEAD",
info:"Informa\u00E7\u00E3o",
add_title:"TITLE",
add_meta:"META",
add_script:"SCRIPT",
add_style:"STYLE",
add_link:"LINK",
add_base:"BASE",
add_comment:"Coment\u00E1rio",
title_element:"TITLE",
script_element:"SCRIPT",
style_element:"STYLE",
base_element:"BASE",
link_element:"LINK",
meta_element:"META",
comment_element:"Coment\u00E1rio",
src:"Src",
language:"Linguagem",
href:"Href",
target:"Alvo",
type:"Tipo",
charset:"Charset",
defer:"Adiar",
media:"M\u00EDdia",
properties:"Propriedades",
name:"Nome",
value:"Valor",
content:"Conte\u00FAdo",
rel:"rel",
rev:"rev",
hreflang:"Href lang",
general_props:"Geral",
advanced_props:"Avan\u00E7ado"
});