tinyMCE.addI18n('nl.table_dlg',{
general_tab:"Algemeen",
advanced_tab:"Geavanceerd",
general_props:"Algemene eigenschappen",
advanced_props:"Geavanceerde eigenschappen",
rowtype:"Rijtype",
title:"Table invoegen/bewerken",
width:"Breedte",
height:"Hoogte",
cols:"Kolommen",
rows:"Rijen",
cellspacing:"Ruimte om cel",
cellpadding:"Ruimte in cel",
border:"Rand",
align:"Uitlijning",
align_default:"Standaard",
align_left:"Links",
align_right:"Rechts",
align_middle:"Centreren",
row_title:"Rij-eigenschappen",
cell_title:"Celeigenschappen",
cell_type:"Celtype",
valign:"Verticale uitlijning",
align_top:"Boven",
align_bottom:"Onder",
bordercolor:"Randkleur",
bgcolor:"Achtergrondkleur",
merge_cells_title:"Cellen samenvoegen",
id:"Id",
style:"Stijl",
langdir:"Taalrichting",
langcode:"Taalcode",
mime:"Doel MIME type",
ltr:"Van links naar rechts",
rtl:"Van rechts naar links",
bgimage:"Achtergrondafbeelding",
summary:"Samenvatting",
td:"Gegevens",
th:"Kop",
cell_cell:"Huidige cel bijwerken",
cell_row:"Alle cellen in rij bijwerken",
cell_all:"Alle cellen in tabel bijwerken",
row_row:"Huidige rij bijwerken",
row_odd:"Oneven rijen bijwerken",
row_even:"Even rijen bijwerken",
row_all:"Alle rijen bijweken",
thead:"Tabelkop",
tbody:"Tabellichaam",
tfoot:"Tabelvoet",
scope:"Bereik",
rowgroup:"Rijgroep",
colgroup:"Kolomgroep",
col_limit:"Je hebt het maximale aantal kolommen van {$cols} overschreden.",
row_limit:"Je hebt het maximale aantal rijen van {$rows} overschreden.",
cell_limit:"Je hebt het maximale aantal cellen van {$cells} overschreden.",
missing_scope:"Weet je zeker dat je door wilt gaan met het toewijzen van een kop zonder een bereik op te geven? Mensen met een visuele handicap kunnen hierdoor waarschijnlijk slecht bij de gegevens.",
caption:"Tabelbeschrijving",
frame:"Frame",
frame_none:"Geen",
frame_groups:"Groepen",
frame_rows:"Rijen",
frame_cols:"Kolommen",
frame_all:"Alles",
rules:"Hulplijnen",
rules_void:"Geen",
rules_above:"Boven",
rules_below:"Onder",
rules_hsides:"Horizontale zijdes",
rules_lhs:"Linkerzijkant",
rules_rhs:"Rechterzijkant",
rules_vsides:"Verticale zijdes",
rules_box:"Box",
rules_border:"Rand"
});