tinyMCE.addI18n('it.fullpage_dlg',{
title:"Propriet\u00E0 Documento",
meta_tab:"Generale",
appearance_tab:"Aspetto",
advanced_tab:"Avanzate",
meta_props:"Informazioni Metatag",
langprops:"Lingua e codifica",
meta_title:"Titolo",
meta_keywords:"Parole chiave",
meta_description:"Descrizione",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"Codice lingua",
langdir:"Direzione testo",
ltr:"Sinistra verso destra",
rtl:"Destra verso sinistra",
xml_pi:"Dichiarazione XML",
encoding:"Codifica carattere",
appearance_bgprops:"Propriet\u00E0 sfondo",
appearance_marginprops:"Margini body",
appearance_linkprops:"Colori collegamenti",
appearance_textprops:"Propriet\u00E0 testo",
bgcolor:"Colore sfondo",
bgimage:"Immagine sfondo",
left_margin:"Margine sinistro",
right_margin:"Margine destro",
top_margin:"Margine superiore",
bottom_margin:"Margine inferiore",
text_color:"Colore testo",
font_size:"Dimensione carattere",
font_face:"Tipo carattere",
link_color:"Colore collegamento",
hover_color:"Colore \'Hover\'",
visited_color:"Colore \'Visited\'",
active_color:"Colore \'Active\'",
textcolor:"Colore",
fontsize:"Dimensione carattere",
fontface:"Famiglia carattere",
meta_index_follow:"Indicizzare e seguire collegamenti",
meta_index_nofollow:"Indicizzare e non segure collegamenti",
meta_noindex_follow:"Non indicizzare ma seguire collegamenti",
meta_noindex_nofollow:"Non indicizzare e non seguire collegamenti",
appearance_style:"Propriet\u00E0 stili e fogli di stile",
stylesheet:"Fogli di stile",
style:"Stile",
author:"Autore",
copyright:"Copyright",
add:"Aggiungi nuovo elemento",
remove:"Rimuovi elemento selezionato",
moveup:"Sposta elemento selezionato in alto",
movedown:"Sposta elemento selezionato in basso",
head_elements:"Elementi Head",
info:"Informazioni",
add_title:"Elemento Titolo",
add_meta:"Elemento Meta",
add_script:"Elemento Script",
add_style:"Elemento Style",
add_link:"Elemento Link",
add_base:"Elemento Base",
add_comment:"Nodo Commento",
title_element:"Elemento Titolo",
script_element:"Elemento Script",
style_element:"Elemento Style",
base_element:"Elemento Base",
link_element:"Elemento Link",
meta_element:"Elemento Meta",
comment_element:"Commento",
src:"Sorgente",
language:"Linguaggio",
href:"Href",
target:"Target",
type:"Tipo",
charset:"Set caratteri",
defer:"Defer",
media:"Media",
properties:"Propriet\u00E0",
name:"Nome",
value:"Valore",
content:"Contenuto",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Generale",
advanced_props:"Avanzate"
});