tinyMCE.addI18n({lv:{
common:{
edit_confirm:"Vai tu v\u0113lies izmantot WYSIWYG \u0161im teksta laukam?",
apply:"Apstiprin\u0101t",
insert:"Ievietot",
update:"Atjaunin\u0101t",
cancel:"Atcelt",
close:"Aizv\u0113rt",
browse:"P\u0101rl\u016Bkot",
class_name:"Klase",
not_set:"-- Nav nor\u0101d\u012Bts --",
clipboard_msg:"Iesp\u0113ja Kop\u0113t/Izgriezt/Iekop\u0113t nav pieejama p\u0101rl\u016Bkiem Mozilla and Firefox.\nVai J\u016Bs v\u0113laties uzzin\u0101t vair\u0101k par \u0161o probl\u0113mu?",
clipboard_no_support:"\u0160obr\u012Bd J\u016Bsu p\u0101rl\u016Bks neatbalsta \u0161o iesp\u0113ju, t\u0101 viet\u0101 l\u016Bdzu izmantotjiet tastat\u016Bras sa\u012Bsin\u0101jumtausti\u0146us.",
popup_blocked:"Atvainojiet, bet m\u0113s esam konstat\u0113ju\u0161i, ka J\u016Bsu uzleco\u0161o logu blo\u0137\u0113t\u0101js ir atsp\u0113jojis logu, kas nodro\u0161ina programmas funkcionalit\u0101ti. Lai piln\u012Bb\u0101 izmantotu \u0161o r\u012Bku, Jums ir j\u0101atsl\u0113dz uzleco\u0161o logu blo\u0137\u0113tajs \u0161ai vietnei. ",
invalid_data:"K\u013C\u016Bda: Ievad\u012Btas neder\u012Bgas v\u0113rt\u012Bbas. T\u0101s ir atz\u012Bm\u0113tas sarkan\u0101 kr\u0101s\u0101.",
more_colors:"Vair\u0101k kr\u0101su"
},
contextmenu:{
align:"Novietojums",
left:"Pa kreisi",
center:"Centr\u0113ts",
right:"Pa labi",
full:"Pilns"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Ievietot datumu",
inserttime_desc:"Ievietot laiku",
months_long:"Janv\u0101ris,Febru\u0101ris,Marts,Apr\u012Blis,Maijs,J\u016Bnijs,J\u016Blijs,Augusts,Seprembris,Oktobris,Novembris,Decembris",
months_short:"Jan,Feb,Mar,Apr,Mai,J\u016Bn,J\u016Bl,Aug,Sep,Okt,Nov,Dec",
day_long:"Sv\u0113tdiena,Pirmdiena,Otrdiena,Tre\u0161diena,Ceturtdiena,Piektdiena,Sestdiena,Sv\u0113tdiena",
day_short:"Sv\u0113,Pir,Otr,Tre,Cet,Pie,Ses,Sv\u0113"
},
print:{
print_desc:"Druk\u0101t"
},
preview:{
preview_desc:"Priek\u0161skat\u012Bt"
},
directionality:{
ltr_desc:"Virziens no kreis\u0101s uz labo",
rtl_desc:"Virziens no lab\u0101s uz kreiso"
},
layer:{
insertlayer_desc:"Ievietot jaunu sl\u0101ni",
forward_desc:"Uz priek\u0161u",
backward_desc:"Atpaka\u013C",
absolute_desc:"Iestat\u012Bt/Nov\u0101kt absol\u016Bto novietojumu ",
content:"Jauns sl\u0101nis..."
},
save:{
save_desc:"Saglab\u0101t",
cancel_desc:"Atcelt visas izmai\u0146as"
},
nonbreaking:{
nonbreaking_desc:"Ievietot tuk\u0161uma simbolu"
},
iespell:{
iespell_desc:"Uzs\u0101kt pareizrakst\u012Bbas p\u0101rbaudi",
download:"ieSpell netika atrasts. Vai J\u016Bs v\u0113laties to uzst\u0101d\u012Bt?"
},
advhr:{
advhr_desc:"Horizont\u0101la sv\u012Btra"
},
emotions:{
emotions_desc:"Smaidi\u0146i"
},
searchreplace:{
search_desc:"Mekl\u0113t",
replace_desc:"Mekl\u0113t/Aizvietot"
},
advimage:{
image_desc:"Ievietot/Redi\u0123\u0113t att\u0113lu"
},
advlink:{
link_desc:"Ievietot/Redi\u0123\u0113t saiti"
},
xhtmlxtras:{
cite_desc:"Citation",
abbr_desc:"Abbreviation",
acronym_desc:"Acronym",
del_desc:"Deletion",
ins_desc:"Insertion",
attribs_desc:"Insert/Edit Attributes"
},
style:{
desc:"Edit CSS Style"
},
paste:{
paste_text_desc:"Paste as Plain Text",
paste_word_desc:"Paste from Word",
selectall_desc:"Select All"
},
paste_dlg:{
text_title:"Use CTRL+V on your keyboard to paste the text into the window.",
text_linebreaks:"Keep linebreaks",
word_title:"Use CTRL+V on your keyboard to paste the text into the window."
},
table:{
desc:"Inserts a new table",
row_before_desc:"Insert row before",
row_after_desc:"Insert row after",
delete_row_desc:"Delete row",
col_before_desc:"Insert column before",
col_after_desc:"Insert column after",
delete_col_desc:"Remove column",
split_cells_desc:"Split merged table cells",
merge_cells_desc:"Merge table cells",
row_desc:"Table row properties",
cell_desc:"Table cell properties",
props_desc:"Table properties",
paste_row_before_desc:"Paste table row before",
paste_row_after_desc:"Paste table row after",
cut_row_desc:"Cut table row",
copy_row_desc:"Copy table row",
del:"Delete table",
row:"Row",
col:"Column",
cell:"Cell"
},
autosave:{
unload_msg:"The changes you made will be lost if you navigate away from this page."
},
fullscreen:{
desc:"Toggle fullscreen mode"
},
media:{
desc:"Insert / edit embedded media",
edit:"Edit embedded media"
},
fullpage:{
desc:"Document properties"
},
template:{
desc:"Insert predefined template content"
},
visualchars:{
desc:"Visual control characters on/off."
},
spellchecker:{
desc:"Toggle spellchecker",
menu:"Spellchecker settings",
ignore_word:"Ignore word",
ignore_words:"Ignore all",
langs:"Languages",
wait:"Please wait...",
sug:"Suggestions",
no_sug:"No suggestions",
no_mpell:"No misspellings found."
},
pagebreak:{
desc:"Insert page break."
}}});