tinyMCE.addI18n('zh.media_dlg',{
title:" \u63D2\u5165 / \u7DE8\u8F2F \u5A92\u9AD4 ",
general:" \u4E00\u822C ",
advanced:" \u9032\u968E ",
file:" \u6587\u4EF6\u5730\u5740 ",
list:" \u5217\u8868 ",
size:" \u5C3A\u5BF8 ",
preview:" \u9810\u89BD ",
constrain_proportions:" \u5F37\u5236\u5C6C\u6027 ",
type:" \u985E\u578B ",
id:"Id",
name:"\u540D\u7A31",
class_name:"Class",
vspace:" \u5782\u76F4\u9593\u8DDD ",
hspace:" \u6C34\u5E73\u9593\u8DDD ",
play:" \u81EA\u52D5\u64AD\u653E ",
loop:" \u5FAA\u74B0 ",
menu:" \u986F\u793A\u83DC\u55AE ",
quality:" \u54C1\u8CEA ",
scale:" \u6BD4\u4F8B ",
align:"\u6392\u5217",
salign:"SAlign",
wmode:"WMode",
bgcolor:" \u80CC\u666F ",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:" \u7DE9\u5B58 ",
hidden:" \u96B1\u85CF ",
controller:"\u63A7\u5236\u5668",
kioskmode:"Kiosk \u6A21\u5F0F",
playeveryframe:"\u64AD\u653E\u6BCF\u4E00\u5E40",
targetcache:"Target cache",
correction:"No correction",
enablejavascript:" \u5141\u8A31 JavaScript",
starttime:" \u958B\u59CB\u6642\u9593 ",
endtime:" \u7D50\u675F\u6642\u9593 ",
href:"Href",
qtsrcchokespeed:"\u963B\u585E\u901F\u5EA6",
target:"\u76EE\u6A19",
volume:" \u97F3\u91CF ",
autostart:" \u81EA\u52D5\u958B\u59CB ",
enabled:"\u555F\u52D5",
fullscreen:" \u5168\u5C4F ",
invokeurls:"\u89F8\u767CURLs",
mute:"Mute",
stretchtofit:"\u4F38\u5C55\u5230\u9069\u5408\u5927\u5C0F",
windowlessvideo:"\u7121\u7A97\u9AD4\u8996\u983B",
balance:"\u5E73\u8861",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"\u7576\u524D\u6A19\u8A18",
currentposition:"\u7576\u524D\u4F4D\u7F6E",
defaultframe:"\u9ED8\u8A8D\u5E40",
playcount:"\u64AD\u653E\u6B21\u6578",
rate:" \u901F\u5EA6 ",
uimode:"UI Mode",
flash_options:"Flash \u9078\u9805 ",
qt_options:"Quicktime \u9078\u9805 ",
wmp_options:"Windows media player \u9078\u9805 ",
rmp_options:"Real media player \u9078\u9805 ",
shockwave_options:"Shockwave \u9078\u9805 ",
autogotourl:" \u81EA\u52D5\u8DF3\u8F49 URL",
center:" \u7F6E\u4E2D ",
imagestatus:"\u5716\u50CF\u72C0\u614B",
maintainaspect:"\u4FDD\u6301\u5916\u89C0",
nojava:" \u7981\u6B62 Java",
prefetch:"\u9810\u53D6",
shuffle:"\u96A8\u6A5F\u652A\u4E82",
console:"\u63A7\u5236\u53F0",
numloop:" \u5FAA\u74B0\u6B21\u6578 ",
controls:"\u63A7\u5236",
scriptcallbacks:"Script callbacks",
swstretchstyle:"\u4F38\u5C55 style",
swstretchhalign:"\u4F38\u5C55 H-Align",
swstretchvalign:"\u4F38\u5C55 V-Align",
sound:" \u8072\u97F3 ",
progress:"\u9032\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"\u8ACB\u5728\u9032\u968E\u9078\u9805\u9801\u4E2D\u5C07\u8A2D\u7F6Ertsp\u6D41\u8CC7\u6E90\u7684QT Src\u5C6C\u6027\u3002",
align_top:"\u9802\u90E8",
align_right:"\u9760\u53F3",
align_bottom:"\u5E95\u90E8",
align_left:"\u9760\u5DE6",
align_center:"\u7F6E\u4E2D",
align_top_left:"\u5DE6\u4E0A",
align_top_right:"\u53F3\u4E0A",
align_bottom_left:"\u5DE6\u4E0B",
align_bottom_right:"\u53F3\u4E0B",
flv_options:"Flash \u8996\u983B\u9078\u9805 ",
flv_scalemode:"\u7E2E\u653E\u6A21\u5F0F",
flv_buffer:"\u7DE9\u5B58",
flv_startimage:"\u958B\u59CB\u5716\u7247",
flv_starttime:"\u958B\u59CB\u6642\u9593",
flv_defaultvolume:" \u9810\u8A2D\u97F3\u91CF ",
flv_hiddengui:"\u96B1\u85CF GUI",
flv_autostart:" \u81EA\u52D5\u958B\u59CB ",
flv_loop:" \u5FAA\u74B0 ",
flv_showscalemodes:"\u986F\u793A\u7E2E\u653E\u6A21\u5F0F",
flv_smoothvideo:" \u5E73\u6ED1\u8996\u983B ",
flv_jscallback:"JS Callback"
});