tinyMCE.addI18n('ar.xhtmlxtras_dlg',{
attribute_label_title:"Title",
attribute_label_id:"ID",
attribute_label_class:"Class",
attribute_label_style:"Style",
attribute_label_cite:"Cite",
attribute_label_datetime:"\u0627\u0644\u062A\u0627\u0631\u064A\u062E/\u0627\u0644\u0648\u0642\u062A",
attribute_label_langdir:"\u0627\u062A\u062C\u0627\u0647 \u0627\u0644\u0646\u0635",
attribute_option_ltr:"\u064A\u0633\u0627\u0631 \u0627\u0644\u0649 \u064A\u0645\u064A\u0646",
attribute_option_rtl:"\u064A\u0645\u064A\u0646 \u0627\u0644\u0649 \u064A\u0633\u0627\u0631",
attribute_label_langcode:"\u0627\u0644\u0644\u063A\u0629",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"Events",
attribute_attrib_tab:"Attributes",
general_tab:"\u0639\u0627\u0645",
attrib_tab:"Attributes",
events_tab:"Events",
fieldset_general_tab:"\u0627\u0644\u0625\u0639\u062F\u0627\u062F\u0627\u062A \u0627\u0644\u0639\u0627\u0645\u0629",
fieldset_attrib_tab:"Element Attributes",
fieldset_events_tab:"Element Events",
title_ins_element:"\u0625\u062F\u0631\u0627\u062C Element",
title_del_element:"Deletion Element",
title_acronym_element:"Acronym Element",
title_abbr_element:"Abbreviation Element",
title_cite_element:"Citation Element",
remove:"\u062D\u0630\u0641",
insert_date:"\u0625\u062F\u0631\u0627\u062C \u0627\u0644\u062A\u0627\u0631\u064A\u062E/\u0627\u0644\u0648\u0642\u062A \u0627\u0644\u062D\u0627\u0644\u064A",
option_ltr:"\u064A\u0633\u0627\u0631 \u0627\u0644\u0649 \u064A\u0645\u064A\u0646",
option_rtl:"\u064A\u0645\u064A\u0646 \u0627\u0644\u0649 \u064A\u0633\u0627\u0631",
attribs_title:"\u0625\u062F\u0631\u0627\u062C/\u062A\u062D\u0631\u064A\u0631 Attributes"
});