tinyMCE.addI18n('sk.table_dlg',{
general_tab:"Hlavn\u00E9",
advanced_tab:"Roz\u0161\u00EDren\u00E9",
general_props:"Hlavn\u00E9 vlastnosti",
advanced_props:"Roz\u0161\u00EDren\u00E9 vlastnosti",
rowtype:"Row in table part",
title:"Insert/Modify table",
width:"\u0160\u00EDrka",
height:"V\u00FD\u0161ka",
cols:"St\u013Apce",
rows:"Riadky",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Border",
align:"Alignment",
align_default:"Default",
align_left:"Left",
align_right:"Right",
align_middle:"Center",
row_title:"Table row properties",
cell_title:"Table cell properties",
cell_type:"Cell type",
valign:"Vertical alignment",
align_top:"Top",
align_bottom:"Bottom",
bordercolor:"Border color",
bgcolor:"Background color",
merge_cells_title:"Merge table cells",
id:"ID",
style:"CSS \u0160t\u00FDl",
langdir:"Smer textu",
langcode:"K\u00F3d jazyka",
mime:"Target MIME type",
ltr:"Z \u013Eava do prava",
rtl:"Z prava do \u013Eava",
bgimage:"Obr\u00E1zok pozadia",
summary:"Popis tabu\u013Eky",
td:"D\u00E1ta",
th:"Hlav\u010Dka",
cell_cell:"Aktualizova\u0165 aktu\u00E1lnu bunku",
cell_row:"Aktualizova\u0165 v\u0161etky bunky v riadku",
cell_all:"Aktualizova\u0165 v\u0161etky bunky v tebu\u013Eke",
row_row:"Aktualizova\u0165 aktu\u00E1lny riadok",
row_odd:"Aktualizova\u0165 odd rows in table",
row_even:"Aktualizova\u0165 nep\u00E1rne riadky v tabu\u013Eke",
row_all:"Aktualizova\u0165 v\u0161etky riadky v tabu\u013Eke",
thead:"Hlavi\u010Dka tabu\u013Eky",
tbody:"Telo tabu\u013Eky",
tfoot:"P\u00E4ta tabu\u013Eky",
scope:"Scope",
rowgroup:"Skupina riadkov",
colgroup:"Skupina st\u013Apcov",
col_limit:"You've exceeded the maximum number of columns of {$cols}.",
row_limit:"You've exceeded the maximum number of rows of {$rows}.",
cell_limit:"You've exceeded the maximum number of cells of {$cells}.",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Table caption",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"riadky",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});