tinyMCE.addI18n('zh.simple',{
bold_desc:" \u7C97\u9AD4 (Ctrl+B)",
italic_desc:" \u659C\u9AD4 (Ctrl+I)",
underline_desc:" \u5E95\u7DDA (Ctrl+U)",
striketrough_desc:" \u522A\u9664\u7DDA ",
bullist_desc:" \u9805\u76EE\u7B26\u865F ",
numlist_desc:" \u7DE8\u865F ",
undo_desc:" \u5FA9\u539F (Ctrl+Z)",
redo_desc:" \u91CD\u505A (Ctrl+Y)",
cleanup_desc:" \u6E05\u7406\u5197\u4F59\u4EE3\u78BC "
});