tinyMCE.addI18n('pt.advanced',{
style_select:"Estilos",
font_size:"Tamanho",
fontdefault:"Fam\u00EDlia(Fonte)",
block:"Formata\u00E7\u00E3o",
paragraph:"Par\u00E1grafo",
div:"Div",
address:"Endere\u00E7o",
pre:"Pr\u00E9-formatado",
h1:"Cabe\u00E7alho 1",
h2:"Cabe\u00E7alho 2",
h3:"Cabe\u00E7alho 3",
h4:"Cabe\u00E7alho 4",
h5:"Cabe\u00E7alho 5",
h6:"Cabe\u00E7alho 6",
blockquote:"Cita\u00E7\u00E3o em Bloco",
code:"C\u00F3digo",
samp:"Amostra de c\u00F3digo",
dt:"Termo de Defini\u00E7\u00E3o",
dd:"Descri\u00E7\u00E3o de Defini\u00E7\u00E3o",
bold_desc:"Negrito (Ctrl+B)",
italic_desc:"It\u00E1lico (Ctrl+I)",
underline_desc:"Sublinhado (Ctrl+U)",
striketrough_desc:"Texto Riscado",
justifyleft_desc:"Alinhamento \u00E0 Esquerda",
justifycenter_desc:"Alinhamento central",
justifyright_desc:"Alinhamento \u00E0 Direita",
justifyfull_desc:"Justificar",
bullist_desc:"Lista N\u00E3o-Ordenada",
numlist_desc:"Lista Ordenada",
outdent_desc:"Indentar \u00E0 Esquerda",
indent_desc:"Indentar",
undo_desc:"Desfazer (Ctrl+Z)",
redo_desc:"Refazer (Ctrl+Y)",
link_desc:"Inserir/editar link",
unlink_desc:"Romper link",
image_desc:"Inserir/editar imagem",
cleanup_desc:"Limpar C\u00F3digo Incorreto",
code_desc:"Editar C\u00F3digo de Fonte",
sub_desc:"Subscrito",
sup_desc:"Superscrito",
hr_desc:"Inserir separador horizontal",
removeformat_desc:"Remover formata\u00E7\u00E3o",
custom1_desc:"Sua descri\u00E7\u00E3o personalizada aqui",
forecolor_desc:"Selecionar cor do texto",
backcolor_desc:"Selecionar cor de fundo",
charmap_desc:"Inserir caracteres personalizados",
visualaid_desc:"Alternar Guias/Elementos Invis\u00EDveis",
anchor_desc:"Inserir/editar \u00E2ncora",
cut_desc:"Cortar",
copy_desc:"Copiar",
paste_desc:"Colar",
image_props_desc:"Propriedades de Imagem",
newdocument_desc:"Novo Documento",
help_desc:"Ajuda",
blockquote_desc:"Cita\u00E7\u00E3o em Bloco",
clipboard_msg:"Copiar/Cortar/Colar n\u00E3o est\u00E1 dispon\u00EDvel em Mozilla e Firefox. Deseja mais informa\u00E7\u00F5es sobre isso?",
path:"Endere\u00E7o",
newdocument:"Tem certeza de que deseja apagar tudo?",
toolbar_focus:"Ir para ferramentas - Alt+Q, Ir para o editor - Alt-Z, Ir para endere\u00E7o do elemento - Alt-X",
more_colors:"Mais cores"
});