tinyMCE.addI18n('fa.media_dlg',{
title:"embedded media \u062F\u0631\u062C / \u0648\u06CC\u0631\u0627\u06CC\u0634",
general:"\u0639\u0645\u0648\u0645\u06CC",
advanced:"\u067E\u06CC\u0634\u0631\u0641\u062A\u0647",
file:"File/URL",
list:"\u0644\u06CC\u0633\u062A",
size:"\u0627\u0628\u0639\u0627\u062F",
preview:"\u067E\u06CC\u0634 \u0646\u0645\u0627\u06CC\u0634",
constrain_proportions:"Constrain proportions",
type:"\u0646\u0648\u0639",
id:"\u0634\u0646\u0627\u0633\u0647",
name:"\u0646\u0627\u0645",
class_name:"Class",
vspace:"V-Space",
hspace:"H-Space",
play:"\u0627\u062C\u0631\u0627\u06CC \u062E\u0648\u062F\u06A9\u0627\u0631",
loop:"Loop",
menu:"\u0646\u0645\u0627\u06CC\u0634 \u0645\u0646\u0648",
quality:"\u06A9\u06CC\u0641\u06CC\u062A",
scale:"Scale",
align:"\u062A\u0631\u0627\u0632",
salign:"SAlign",
wmode:"WMode",
bgcolor:"\u067E\u0633 \u0632\u0645\u06CC\u0646\u0647",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Hidden",
controller:"Controller",
kioskmode:"Kiosk mode",
playeveryframe:"Play every frame",
targetcache:"Target cache",
correction:"\u0628\u062F\u0648\u0646 \u062A\u0635\u062D\u06CC\u062D",
enablejavascript:"Enable JavaScript",
starttime:"\u0632\u0645\u0627\u0646 \u0634\u0631\u0648\u0639",
endtime:"\u0632\u0645\u0627\u0646 \u067E\u0627\u06CC\u0627\u0646",
href:"Href",
qtsrcchokespeed:"Choke \u0633\u0631\u0639\u062A",
target:"\u0647\u062F\u0641",
volume:"\u062D\u062C\u0645 \u0635\u062F\u0627",
autostart:"\u0634\u0631\u0648\u0639 \u062E\u0648\u062F\u06A9\u0627\u0631",
enabled:"\u0641\u0639\u0627\u0644",
fullscreen:"\u062A\u0645\u0627\u0645 \u0635\u0641\u062D\u0647",
invokeurls:"Invoke URLs",
mute:"Mute",
stretchtofit:"Stretch to fit",
windowlessvideo:"Windowless video",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Current position",
defaultframe:"Default frame",
playcount:"Play count",
rate:"Rate",
uimode:"UI Mode",
flash_options:"Flash options",
qt_options:"Quicktime options",
wmp_options:"Windows media player options",
rmp_options:"Real media player options",
shockwave_options:"Shockwave options",
autogotourl:"Auto goto URL",
center:"\u0645\u0631\u06A9\u0632",
imagestatus:"\u0648\u0636\u0639\u06CC\u062A \u062A\u0635\u0648\u06CC\u0631",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Console",
numloop:"Num loops",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"\u0635\u062F\u0627",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"\u0628\u0627\u0644\u0627",
align_right:"\u0631\u0627\u0633\u062A",
align_bottom:"\u067E\u0627\u06CC\u06CC\u0646",
align_left:"\u0686\u067E",
align_center:"\u0648\u0633\u0637",
align_top_left:"\u0686\u067E \u0628\u0627\u0644\u0627",
align_top_right:"\u0631\u0627\u0633\u062A \u0628\u0627\u0644\u0627",
align_bottom_left:"\u0686\u067E \u067E\u0627\u06CC\u06CC\u0646",
align_bottom_right:"\u0631\u0627\u0633\u062A \u067E\u0627\u06CC\u06CC\u0646",
flv_options:"Flash video options",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"\u062A\u0635\u0648\u06CC\u0631 \u0634\u0631\u0648\u0639",
flv_starttime:"\u0632\u0645\u0627\u0646 \u0634\u0631\u0648\u0639",
flv_defaultvolume:"\u062D\u062C\u0645 \u067E\u06CC\u0634 \u0641\u0631\u0636 \u0635\u062F\u0627",
flv_hiddengui:"Hidden GUI",
flv_autostart:"\u0634\u0631\u0648\u0639 \u062E\u0648\u062F\u06A9\u0627\u0631",
flv_loop:"Loop",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});