tinyMCE.addI18n('nn.table_dlg',{
general_tab:"Generelt",
advanced_tab:"Avansert",
general_props:"Generelle egenskaper",
advanced_props:"Avanserte egenskaper",
rowtype:"Rad i tabell del",
title:"Opprett/Endre tabell",
width:"Bredde",
height:"H\u00F8yde",
cols:"Kolonner",
rows:"Rader",
cellspacing:"Celle mellomrom",
cellpadding:"Celle fylling",
border:"Ramme",
align:"Justering",
align_default:"Ingen",
align_left:"Venstre",
align_right:"H\u00F8yre",
align_middle:"Sentrert",
row_title:"Tabell rad egenskaper",
cell_title:"Tabell celle egenskaper",
cell_type:"Celle type",
valign:"Vertikal justering",
align_top:"Toppen",
align_bottom:"Bunnen",
bordercolor:"Ramme farge",
bgcolor:"Bakgrunnsfarge",
merge_cells_title:"Sl\u00E5 sammen tabell celler",
id:"Id",
style:"Style",
langdir:"Spr\u00E5k retning",
langcode:"Spr\u00E5k kode",
mime:"M\u00E5l MIME type",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre mot venstre",
bgimage:"Bakgrunnsbilde",
summary:"Sum",
td:"Data",
th:"Overskrift",
cell_cell:"Oppdater valgt celle",
cell_row:"Oppdater alle celler i raden",
cell_all:"Oppdater alle celler i tabellen",
row_row:"Oppdater valgt rad",
row_odd:"Oppdater ulike rader i tabellen",
row_even:"Oppdater like rader i tabellen",
row_all:"Oppdater alle rader i tabellen",
thead:"Tabell Hode",
tbody:"Tabell Kropp",
tfoot:"Tabell Fot",
scope:"Hensikt",
rowgroup:"Rad Gruppe",
colgroup:"Kolonne Gruppe",
col_limit:"Du har overskredet maksimum antall kolonner, maks: {$cols}.",
row_limit:"Du har overskredet maksimum antall rader, maks: {$rows}.",
cell_limit:"Du har overskredet maksimum antall celler, maks: {$cells}.",
missing_scope:"Er du sikker p\u00E5 at du vil fortsette uten \u00E5 oppgi hensikten med denne tabellens hodecelle.",
caption:"Tabell overskrift",
frame:"Frame",
frame_none:"ingen",
frame_groups:"grupper",
frame_rows:"rader",
frame_cols:"kolonner",
frame_all:"alle",
rules:"Regler",
rules_void:"ingen",
rules_above:"over",
rules_below:"under",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"boks",
rules_border:"Ramme"
});