tinyMCE.addI18n('nb.xhtmlxtras_dlg',{
attribute_label_title:"Tittel",
attribute_label_id:"ID",
attribute_label_class:"Klasse",
attribute_label_style:"Stil",
attribute_label_cite:"Henvisning",
attribute_label_datetime:"Dato/Tid",
attribute_label_langdir:"Tekst Retning",
attribute_option_ltr:"Venstre mot h\u00F8yre",
attribute_option_rtl:"H\u00F8yre mot venstre",
attribute_label_langcode:"Spr\u00E5k",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"Begivenhet",
attribute_attrib_tab:"Egenskaper",
general_tab:"Generelt",
attrib_tab:"Attributter",
events_tab:"Begivenhet",
fieldset_general_tab:"Generell Innstilling",
fieldset_attrib_tab:"Element Attributes",
fieldset_events_tab:"Element Events",
title_ins_element:"Insertion Element",
title_del_element:"Deletion Element",
title_acronym_element:"Acronym Element",
title_abbr_element:"Abbreviation Element",
title_cite_element:"Citation Element",
remove:"Remove",
insert_date:"Sett inn dato/tid",
option_ltr:"Venstre mot h\u00F8yre",
option_rtl:"H\u00F8yre mot venstre",
attribs_title:"Opprett/Endre Attributter"
});