tinyMCE.addI18n('cs.fullpage_dlg',{
title:"Vlastnosti dokumentu",
meta_tab:"Hlavn\u00ED",
appearance_tab:"Vzhled",
advanced_tab:"Pokro\u010Dil\u00E9",
meta_props:"Meta informace",
langprops:"Jazyk a k\u00F3dov\u00E1n\u00ED",
meta_title:"Titulek",
meta_keywords:"Keywords",
meta_description:"Description",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"K\u00F3d jazyka",
langdir:"Sm\u011Br textu",
ltr:"Zleva doprava",
rtl:"Zprava doleva",
xml_pi:"XML deklarace",
encoding:"K\u00F3dov\u00E1n\u00ED",
appearance_bgprops:"Vlastnosti pozad\u00ED",
appearance_marginprops:"Body margins",
appearance_linkprops:"Barva odkaz\u016F",
appearance_textprops:"Vlastnosti textu",
bgcolor:"Barva pozad\u00ED",
bgimage:"Obr\u00E1zek na pozad\u00ED",
left_margin:"Left margin",
right_margin:"Right margin",
top_margin:"Top margin",
bottom_margin:"Bottom margin",
text_color:"Text color",
font_size:"Velikost p\u00EDsma",
font_face:"P\u00EDsmo",
link_color:"Barva odkazu",
hover_color:"Barva \"hover\"",
visited_color:"Barva \"visited\"",
active_color:"Aktivn\u00ED barva",
textcolor:"Barva",
fontsize:"Velikost fontu",
fontface:"Rodina font\u016F",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don't follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\'t follow the links",
appearance_style:"Form\u00E1tovac\u00ED sada a vlastnosti styl\u016F",
stylesheet:"Form\u00E1tovac\u00ED sada",
style:"Styl",
author:"Autor",
copyright:"Copyright",
add:"P\u0159idat nov\u00FD element",
remove:"Odebrat ozna\u010Den\u00FD element",
moveup:"P\u0159esu\u0148 ozna\u010Den\u00FD element v\u00FD\u0161",
movedown:"P\u0159esu\u0148 ozna\u010Den\u00FD element n\u00ED\u017E",
head_elements:"Hlavi\u010Dky",
info:"Informace",
add_title:"Title element",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Style element",
add_link:"Link element",
add_base:"Base element",
add_comment:"Comment element",
title_element:"Title element",
script_element:"Script element",
style_element:"Style element",
base_element:"Base element",
link_element:"Link element",
meta_element:"Meta element",
comment_element:"Comment element",
src:"Src",
language:"Jazyk",
href:"Href",
target:"Target",
type:"Type",
charset:"Znakov\u00E1 sada",
defer:"Defer",
media:"Media",
properties:"Vlastnosti",
name:"N\u00E1zev",
value:"Hodnota",
content:"Obsah",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"Hlavn\u00ED",
advanced_props:"Pokro\u010Dil\u00E9"
});