tinyMCE.addI18n('zh.fullpage_dlg',{
title:"\u6587\u4EF6\u5C6C\u6027",
meta_tab:"\u4E00\u822C",
appearance_tab:"\u5916\u89C0",
advanced_tab:"\u9032\u968E",
meta_props:"Meta \u4FE1\u606F",
langprops:"\u8A9E\u8A00\u548C\u7DE8\u78BC",
meta_title:"\u6A19\u984C",
meta_keywords:"\u95DC\u9375\u8A5E",
meta_description:"\u8AAA\u660E",
meta_robots:"Robots",
doctypes:"Doctype",
langcode:"\u8A9E\u8A00\u4EE3\u78BC",
langdir:"\u8A9E\u8A00\u65B9\u5411",
ltr:"\u5F9E\u5DE6\u5230\u53F3",
rtl:"\u5F9E\u53F3\u5230\u5DE6",
xml_pi:"XML \u8072\u660E",
encoding:"\u5B57\u7B26\u96C6\u7DE8\u78BC",
appearance_bgprops:"\u80CC\u666F\u5C6C\u6027",
appearance_marginprops:"Body margins",
appearance_linkprops:"\u9023\u7D50\u984F\u8272",
appearance_textprops:"\u6587\u5B57\u5C6C\u6027",
bgcolor:"\u80CC\u666F\u984F\u8272",
bgimage:"\u80CC\u666F\u5716\u7247",
left_margin:"Left margin",
right_margin:"Right margin",
top_margin:"Top margin",
bottom_margin:"Bottom margin",
text_color:"\u6587\u672C\u984F\u8272",
font_size:"\u5B57\u865F",
font_face:"\u5B57\u578B\u540D\u7A31",
link_color:"\u9023\u7D50\u984F\u8272",
hover_color:"Hover\u984F\u8272",
visited_color:"\u8A2A\u554F\u5F8C\u984F\u8272",
active_color:"Active color",
textcolor:"\u984F\u8272",
fontsize:"\u5B57\u865F",
fontface:"\u5B57\u578B\u540D\u7A31",
meta_index_follow:"Index and follow the links",
meta_index_nofollow:"Index and don ' t follow the links",
meta_noindex_follow:"Do not index but follow the links",
meta_noindex_nofollow:"Do not index and don\ ' t follow the links",
appearance_style:"Stylesheet and style properties",
stylesheet:"Stylesheet",
style:"Style",
author:"Author",
copyright:"Copyright",
add:"Add new element",
remove:"Remove selected element",
moveup:"Move selected element up",
movedown:"Move selected element down",
head_elements:"Head elements",
info:"Information",
add_title:"Title element",
add_meta:"Meta element",
add_script:"Script element",
add_style:"Style element",
add_link:"Link element",
add_base:"Base element",
add_comment:"Comment node",
title_element:"Title element",
script_element:"Script element",
style_element:"Style element",
base_element:"Base element",
link_element:"Link element",
meta_element:"Meta element",
comment_element:"Comment",
src:"Src",
language:"Language",
href:"Href",
target:"Target",
type:"Type",
charset:"Charset",
defer:"Defer",
media:"Media",
properties:"\u5C6C\u6027",
name:"\u540D\u7A31",
value:"\u503C",
content:"\u5167\u5BB9",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"General",
advanced_props:"Advanced"
});