tinyMCE.addI18n('zh.xhtmlxtras_dlg',{
attribute_label_title:"\u6A19\u984C",
attribute_label_id:"ID",
attribute_label_class:"Class",
attribute_label_style:" \u6A23\u5F0F ",
attribute_label_cite:"\u5F15\u7528",
attribute_label_datetime:" \u65E5\u671F / \u6642\u9593 ",
attribute_label_langdir:" \u6587\u5B57\u65B9\u5411 ",
attribute_option_ltr:" \u5F9E\u5DE6\u5411\u53F3 ",
attribute_option_rtl:" \u5F9E\u53F3\u5411\u5DE6 ",
attribute_label_langcode:" \u8A9E\u8A00 ",
attribute_label_tabindex:"Tab \u9806\u5E8F ",
attribute_label_accesskey:" \u5FEB\u901F\u9375 ",
attribute_events_tab:" \u4E8B\u4EF6 ",
attribute_attrib_tab:" \u5C6C\u6027 ",
general_tab:" \u4E00\u822C ",
attrib_tab:" \u5C6C\u6027 ",
events_tab:" \u4E8B\u4EF6 ",
fieldset_general_tab:" \u4E00\u822C\u8A2D\u7F6E ",
fieldset_attrib_tab:" \u5143\u7D20\u5C6C\u6027 ",
fieldset_events_tab:" \u5143\u7D20\u4E8B\u4EF6 ",
title_ins_element:" \u63D2\u5165\u5143\u7D20 ",
title_del_element:" \u522A\u9664\u5143\u7D20 ",
title_acronym_element:"\u9996\u5B57\u6BCD\u7E2E\u5BEB\u5143\u7D20",
title_abbr_element:"\u7E2E\u5BEB\u5143\u7D20",
title_cite_element:"\u5F15\u7528\u5143\u7D20",
remove:" \u522A\u9664 ",
insert_date:" \u63D2\u5165\u7576\u524D \u65E5\u671F / \u6642\u9593 ",
option_ltr:" \u5F9E\u5DE6\u5411\u53F3 ",
option_rtl:" \u5F9E\u53F3\u5411\u5DE6 ",
attribs_title:" \u63D2\u5165 / \u7DE8\u8F2F \u5C6C\u6027 "
});