tinyMCE.addI18n('pl.table_dlg',{
general_tab:"G\u0142\u00F3wna",
advanced_tab:"Zaawansowana",
general_props:"G\u0142\u00F3wne w\u0142a\u015Bciwo\u015Bci",
advanced_props:"Zaawansowane w\u0142a\u015Bciwo\u015Bci",
rowtype:"Row in table part",
title:"Wklej/Zmie\u0144 tabel\u0119",
width:"Szeroko\u015B\u0107",
height:"Wysoko\u015B\u0107",
cols:"Kolumny",
rows:"Wiersze",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Ramka",
align:"Wyr\u00F3wnanie",
align_default:"Domy\u015Blnie",
align_left:"Lewy",
align_right:"Prawy",
align_middle:"\u015Arodek",
row_title:"W\u0142a\u015Bciwo\u015Bci wiersza",
cell_title:"W\u0142a\u015Bciwo\u015Bci kom\u00F3rki",
cell_type:"Cell type",
valign:"Pionowe wyr\u00F3wnanie",
align_top:"G\u00F3ra",
align_bottom:"D\u00F3\u0142",
bordercolor:"Kolor ramki",
bgcolor:"Kolor t\u0142a",
merge_cells_title:"Po\u0142\u0105cz kom\u00F3rki",
id:"Id",
style:"Styl",
langdir:"Language direction",
langcode:"Language code",
mime:"Target MIME type",
ltr:"Kierunek z lewej do prawej",
rtl:"Kierunek z prawej do lewej",
bgimage:"Background image",
summary:"Summary",
td:"Data",
th:"Header",
cell_cell:"Update current cell",
cell_row:"Update all cells in row",
cell_all:"Update all cells in table",
row_row:"Update current row",
row_odd:"Update odd rows in table",
row_even:"Update even rows in table",
row_all:"Update all rows in table",
thead:"Table Head",
tbody:"Table Body",
tfoot:"Table Foot",
scope:"Zakres",
rowgroup:"Row Group",
colgroup:"Col Group",
col_limit:"Przekroczy\u0142e\u015B maksymaln\u0105 liczb\u0119 kolumn of {$cols}.",
row_limit:"Przekroczy\u0142e\u015B maksymaln\u0105 liczb\u0119 kolumn {$rows}.",
cell_limit:"Przekroczy\u0142e\u015B maksymaln\u0105 liczb\u0119 cells of {$cells}.",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Nag\u0142\u00F3wek tabeli",
frame:"Ramka",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"wszystkie",
rules:"Zasady",
rules_void:"void",
rules_above:"nad",
rules_below:"pod",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});