tinyMCE.addI18n('hu.style_dlg',{
title:"CSS Style szerkest\u00E9se",
apply:"Alkalmaz",
text_tab:"Sz\u00F6veg",
background_tab:"H\u00E1tt\u00E9r",
block_tab:"Blokk",
box_tab:"Doboz",
border_tab:"Keret",
list_tab:"Lista",
positioning_tab:"Poz\u00EDci\u00F3",
text_props:"Sz\u00F6veg",
text_font:"Bet\u0171t\u00EDpus",
text_size:"M\u00E9ret",
text_weight:"Sz\u00E9less\u00E9g",
text_style:"St\u00EDlus",
text_variant:"V\u00E1ltozat",
text_lineheight:"Sormagass\u00E1g",
text_case:"eset",
text_color:"sz\u00EDn",
text_decoration:"dekor\u00E1ci\u00F3",
text_overline:"fel\u00FClh\u00FAz\u00E1s",
text_underline:"alulh\u00FAz\u00E1s",
text_striketrough:"\u00E1th\u00FAz\u00E1s",
text_blink:"villog\u00E1s",
text_none:"egyik sem",
background_color:"H\u00E1tt\u00E9rsz\u00EDn",
background_image:"H\u00E1tt\u00E9rk\u00E9p",
background_repeat:"Ism\u00E9tl\u00E9s",
background_attachment:"Csatolm\u00E1ny",
background_hpos:"V\u00EDzszintes hely",
background_vpos:"F\u00FCgg\u0151leges hely",
block_wordspacing:"Sz\u00F3t\u00E1vols\u00E1g",
block_letterspacing:"Bet\u0171 t\u00E1vols\u00E1g",
block_vertical_alignment:"F\u00FCgg\u0151leges igaz\u00EDt\u00E1s",
block_text_align:"Sz\u00F6veg igaz\u00EDt\u00E1s",
block_text_indent:"Sz\u00F6veg beh\u00FAz\u00E1s",
block_whitespace:"\u00DCres helyek",
block_display:"Megjelen\u00EDt\u00E9s",
box_width:"Sz\u00E9less\u00E9g",
box_height:"Magass\u00E1g",
box_float:"Lebeg\u00E9s",
box_clear:"Takar\u00EDt\u00E1s",
padding:"bels\u0151 marg\u00F3",
same:"Mindenhol ugyanaz",
top:"Fel\u00FCl",
right:"Jobbra",
bottom:"Lent",
left:"Balra",
margin:"Marg\u00F3",
style:"St\u00EDlus",
width:"Sz\u00E9less\u00E9g",
height:"Magass\u00E1g",
color:"Sz\u00EDn",
list_type:"T\u00EDpus",
bullet_image:"Wlemk\u00E9p",
position:"Poz\u00EDci\u00F3",
positioning_type:"T\u00EDpus",
visibility:"L\u00E1that\u00F3s\u00E1g",
zindex:"Z-index",
overflow:"Kifut\u00E1s",
placement:"Elhelyez\u00E9s",
clip:"Lev\u00E1g\u00E1s"
});