tinyMCE.addI18n('zh.table_dlg',{
general_tab:" \u4E00\u822C ",
advanced_tab:" \u9032\u968E ",
general_props:" \u4E00\u822C\u8A2D\u7F6E ",
advanced_props:" \u9032\u968E\u8A2D\u7F6E ",
rowtype:" \u884C\u6240\u5C6C\u90E8\u5206 ",
title:" \u63D2\u5165 / \u7DE8\u8F2F \u8868\u683C ",
width:" \u5BEC\u5EA6 ",
height:" \u9AD8\u5EA6 ",
cols:" \u884C\u6578 ",
rows:" \u5217\u6578 ",
cellspacing:" \u9593\u8DDD ",
cellpadding:" \u896F\u8DDD ",
border:" \u908A\u6846 ",
align:" \u5C0D\u9F4A\u65B9\u5F0F ",
align_default:" \u9ED8\u8A8D ",
align_left:" \u9760\u5DE6\u5C0D\u9F4A ",
align_right:" \u9760\u53F3\u5C0D\u9F4A ",
align_middle:" \u7F6E\u4E2D ",
row_title:" \u884C\u5C6C\u6027 ",
cell_title:" \u5217\u5C6C\u6027 ",
cell_type:" \u5132\u5B58\u683C\u985E\u578B ",
valign:" \u5782\u76F4\u5C0D\u9F4A ",
align_top:" \u9802\u7AEF ",
align_bottom:" \u5E95\u90E8 ",
bordercolor:" \u908A\u6846\u984F\u8272 ",
bgcolor:" \u80CC\u666F\u984F\u8272 ",
merge_cells_title:" \u5408\u4F75\u5132\u5B58\u683C ",
id:"Id",
style:" \u6A23\u5F0F ",
langdir:" \u8A9E\u8A00\u65B9\u5411 ",
langcode:" \u8A9E\u8A00\u4EE3\u78BC ",
mime:" \u76EE\u6A19 MIME \u985E\u578B ",
ltr:" \u5F9E\u5DE6\u81F3\u53F3 ",
rtl:" \u5F9E\u53F3\u81F3\u5DE6 ",
bgimage:" \u80CC\u666F\u5716\u7247 ",
summary:"Summary",
td:" \u5167\u5BB9\u5132\u5B58\u683C ",
th:" \u6A19\u984C\u5132\u5B58\u683C ",
cell_cell:" \u66F4\u65B0\u76EE\u524D\u7684\u5132\u5B58\u683C ",
cell_row:" \u66F4\u65B0\u6240\u5C6C\u884C\u5132\u5B58\u683C ",
cell_all:" \u66F4\u65B0\u5168\u90E8\u5132\u5B58\u683C ",
row_row:" \u66F4\u65B0\u6240\u8655\u884C ",
row_odd:" \u66F4\u65B0\u5947\u6578\u884C ",
row_even:" \u66F4\u65B0\u5076\u6578\u884C ",
row_all:" \u66F4\u65B0\u6240\u6709\u884C ",
thead:" \u8868\u683C\u9801\u7709 ",
tbody:" \u8868\u683C\u6B63\u6587 ",
tfoot:" \u8868\u683C\u9801\u8173 ",
scope:" \u7BC4\u570D ",
rowgroup:" \u884C\u7D44 ",
colgroup:" \u5217\u7D44 ",
col_limit:" \u5DF2\u5230\u9054\u5217\u6700\u5927\u503C { $cols } .",
row_limit:" \u5DF2\u5230\u9054\u884C\u6700\u5927\u503C { $rows } .",
cell_limit:" \u5DF2\u5230\u9054\u5132\u5B58\u683C\u6700\u5927\u503C { $cells } .",
missing_scope:"Are you sure you want to continuewithout specifying a scope for this table header cell. Without it, itmay be difficult for some users with disabilities to understand thecontent or data displayed of the table.",
caption:" \u8868\u683C\u6A19\u984C ",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});