tinyMCE.addI18n('nb.advimage_dlg',{
tab_general:"Generelle innstillinger",
tab_appearance:"Visuelle innstillinger",
tab_advanced:"Avanserte innstillinger",
general:"Generelt",
title:"Tittel",
preview:"Forh\u00E5ndsvisning",
constrain_proportions:"Behold proporsjonen",
langdir:"Spr\u00E5k retning",
langcode:"Spr\u00E5k kode",
long_desc:"Spr\u00E5k beskrivelse",
style:"Stil",
classes:"CSS klasser",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre mot venstre",
id:"Id",
map:"Bilde map",
swap_image:"Bytt bilde",
alt_image:"Alternativt bilde",
mouseover:"for musepeker over",
mouseout:"for musepeker utenfor",
misc:"Forskjellig",
example_img:"Forh\u00E5ndsvisningsbilde",
missing_alt:"Er du sikker p\u00E5 at du vil fortsette uten \u00E5 sette inn en beskrivelse av bildet?",
dialog_title:"Opprett/endre bilde",
src:"Bilde URL",
alt:"Bilde beskrivelse",
list:"Bilde liste",
border:"Ramme",
dimensions:"Dimensjon",
vspace:"Vertikal luft",
hspace:"Horisontal luft",
align:"Justering",
align_baseline:"Baseline",
align_top:"Topp",
align_middle:"Midtstilt",
align_bottom:"Bunnen",
align_texttop:"Tekst toppen",
align_textbottom:"Tekst bunnen",
align_left:"Venstre",
align_right:"H\u00F8yre",
image_list:"Bilde liste"
});