tinyMCE.addI18n('sv.style_dlg',{
title:"Redigera inline CSS",
apply:"Applicera",
text_tab:"Text",
background_tab:"Bakgrund",
block_tab:"Block",
box_tab:"Box",
border_tab:"Ramar",
list_tab:"Listor",
positioning_tab:"Positionering",
text_props:"Text",
text_font:"Typsnitt",
text_size:"Storlek",
text_weight:"Tjocklek",
text_style:"Stil",
text_variant:"Variant",
text_lineheight:"Radh\u00F6jd",
text_case:"Sm\u00E5/stora",
text_color:"F\u00E4rg",
text_decoration:"Dekoration",
text_overline:"\u00D6verstruken",
text_underline:"Understruken",
text_striketrough:"Genomstruken",
text_blink:"Blinka",
text_none:"Inget",
background_color:"Bakgrundsf\u00E4rg",
background_image:"Bakgrundsbild",
background_repeat:"Upprepning",
background_attachment:"F\u00E4stpunkt",
background_hpos:"Horisontell position",
background_vpos:"Vertikal position",
block_wordspacing:"Ordavbrytning",
block_letterspacing:"Teckenmellanrum",
block_vertical_alignment:"Vertikal justering",
block_text_align:"Textjustering",
block_text_indent:"Textindrag",
block_whitespace:"Whitespace",
block_display:"Display",
box_width:"Bredd",
box_height:"H\u00F6jd",
box_float:"Float",
box_clear:"Clear",
padding:"Padding",
same:"Samma f\u00F6r alla",
top:"Toppen",
right:"H\u00F6ger",
bottom:"Botten",
left:"V\u00E4nster",
margin:"Marginal",
style:"Stil",
width:"Bredd",
height:"H\u00F6jd",
color:"F\u00E4rg",
list_type:"Listtyp",
bullet_image:"Punktbild",
position:"Position",
positioning_type:"Positionstyp",
visibility:"Synlighet",
zindex:"Z-index",
overflow:"\u00D6verfl\u00F6de",
placement:"Placering",
clip:"Besk\u00E4rning"
});