tinyMCE.addI18n('es.xhtmlxtras_dlg',{
attribute_label_title:"Titulo",
attribute_label_id:"ID",
attribute_label_class:"Clase",
attribute_label_style:"Estilo",
attribute_label_cite:"Cite",
attribute_label_datetime:"Fecha/Hora",
attribute_label_langdir:"Direccion de texto",
attribute_option_ltr:"Izquierda a derecha",
attribute_option_rtl:"Derecha a izquierda",
attribute_label_langcode:"Lenguaje",
attribute_label_tabindex:"Orden de tabulacion",
attribute_label_accesskey:"Tecla de acceso",
attribute_events_tab:"Eventos",
attribute_attrib_tab:"Atributos",
general_tab:"General",
attrib_tab:"Atributos",
events_tab:"Eventos",
fieldset_general_tab:"Configuracion general",
fieldset_attrib_tab:"Atributos del elemento",
fieldset_events_tab:"Evento del elemento",
title_ins_element:"Insertion Element",
title_del_element:"Deletion Element",
title_acronym_element:"Acronym Element",
title_abbr_element:"Abbreviation Element",
title_cite_element:"Citation Element",
remove:"Suprimir",
insert_date:"Insertar fecha/hora actual",
option_ltr:"Izquierda a derecha",
option_rtl:"Derecha a izquierda",
attribs_title:"Insertar/Editar atributos"
});