tinyMCE.addI18n('ja.media_dlg',{
title:"\u30E1\u30C7\u30A3\u30A2\u306E\u633F\u5165/\u7DE8\u96C6",
general:"\u4E00\u822C",
advanced:"\u9AD8\u5EA6",
file:"\u30D5\u30A1\u30A4\u30EB/URL",
list:"\u4E00\u89A7",
size:"\u30B5\u30A4\u30BA",
preview:"\u30D7\u30EC\u30D3\u30E5\u30FC",
constrain_proportions:"\u30A2\u30B9\u30DA\u30AF\u30C8\u6BD4\u4FDD\u5B58",
type:"\u30BF\u30A4\u30D7",
id:"Id",
name:"Name",
class_name:"Class",
vspace:"\u4E0A\u4E0B\u4E88\u7D04",
hspace:"\u5DE6\u53F3\u4F59\u767D",
play:"\u81EA\u52D5\u518D\u751F",
loop:"\u9023\u7D9A\u518D\u751F",
menu:"\u30E1\u30CB\u30E5\u30FC\u8868\u793A",
quality:"\u54C1\u8CEA",
scale:"\u30B9\u30B1\u30FC\u30EB",
align:"Align",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Background",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Hidden",
controller:"Controller",
kioskmode:"Kiosk mode",
playeveryframe:"Play every frame",
targetcache:"Target cache",
correction:"No correction",
enablejavascript:"JavaScript\u3092\u8A31\u53EF",
starttime:"Start time",
endtime:"End time",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Target",
volume:"Volume",
autostart:"Auto start",
enabled:"Enabled",
fullscreen:"Fullscreen",
invokeurls:"Invoke URLs",
mute:"Mute",
stretchtofit:"Stretch to fit",
windowlessvideo:"Windowless video",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Current position",
defaultframe:"Default frame",
playcount:"Play count",
rate:"Rate",
uimode:"UI Mode",
flash_options:"Flash options",
qt_options:"Quicktime options",
wmp_options:"Windows media player options",
rmp_options:"Real media player options",
shockwave_options:"Shockwave options",
autogotourl:"Auto goto URL",
center:"Center",
imagestatus:"Image status",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Console",
numloop:"Num loops",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"Sound",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"Top",
align_right:"Right",
align_bottom:"Bottom",
align_left:"Left",
align_center:"Center",
align_top_left:"Top left",
align_top_right:"Top right",
align_bottom_left:"Bottom left",
align_bottom_right:"Bottom right",
flv_options:"Flash video options",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"Start image",
flv_starttime:"Start time",
flv_defaultvolume:"Default volumne",
flv_hiddengui:"Hidden GUI",
flv_autostart:"Auto start",
flv_loop:"Loop",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});