tinyMCE.addI18n('es.advanced',{
style_select:"Estilos",
font_size:"Tamano de fuente",
fontdefault:"Fuente",
block:"Formato",
paragraph:"Parrafo",
div:"Div",
address:"Direccion",
pre:"Preformateado",
h1:"Encabezado 1",
h2:"Encabezado 2",
h3:"Encabezado 3",
h4:"Encabezado 4",
h5:"Encabezado 5",
h6:"Encabezado 6",
blockquote:"Blockquote",
code:"Codigo",
samp:"Ejemplo de codigo",
dt:"Termino de definicion ",
dd:"Descripcion de definicion",
bold_desc:"Negrita (Ctrl+B)",
italic_desc:"Cursiva (Ctrl+I)",
underline_desc:"Subrayado (Ctrl+U)",
striketrough_desc:"Tachado",
justifyleft_desc:"Alinear a la izquierda",
justifycenter_desc:"Alinear al centro",
justifyright_desc:"Alinear a la derecha",
justifyfull_desc:"Justificar",
bullist_desc:"Lista desordenada",
numlist_desc:"Lista ordenada",
outdent_desc:"Reducir sangria",
indent_desc:"Aumentar sandria",
undo_desc:"Deshacer (Ctrl+Z)",
redo_desc:"Rehacer (Ctrl+Y)",
link_desc:"Insertar/editar hipervinculo",
unlink_desc:"Quitar hipervinculo",
image_desc:"Insertar/editar imagen",
cleanup_desc:"Limpiar codigo sucio",
code_desc:"Editar Fuente HTML",
sub_desc:"Subindice",
sup_desc:"Superindice",
hr_desc:"Insertar regla horizontal",
removeformat_desc:"Remover formato",
custom1_desc:"Su descripcion personal aqui",
forecolor_desc:"Seleccionar color del texto",
backcolor_desc:"Seleccionar color de fondo",
charmap_desc:"Insertar caracteres personalizados",
visualaid_desc:"Mostar/ocultar linea de guia/elementos invisibles",
anchor_desc:"Insertar/editar ancla",
cut_desc:"Cortar",
copy_desc:"Copiar",
paste_desc:"Pegar",
image_props_desc:"Propiedades de imagen",
newdocument_desc:"Nuevo documento",
help_desc:"Ayuda",
blockquote_desc:"Blockquote",
clipboard_msg:"Copiar/Cortar/Pegar no se encuentra disponible en Mozilla y Firefox.\nDesea obtener mas informacion acerca de este tema?",
path:"Ruta",
newdocument:"Esta seguro que desea limpiar todo el contenido?",
toolbar_focus:"Ir a los botones de herramientas - Alt+Q, Ir al editor - Alt-Z, Ir a la ruta del elemento - Alt-X",
more_colors:"Mas colores"
});