tinyMCE.addI18n('es.advlink_dlg',{
title:"Insertar/editar hipervinculo",
url:"URL del hipervinculo",
target:"Destino",
titlefield:"Titulo",
is_email:"La URL que ha ingresado parece ser una direcion de correo, desea agregar el prefijo mailto: necesario?",
is_external:"La URL que ha ingresado parece ser un vinculo externo, desea agregar el prefijo http:// prefijo?",
list:"Lista de vinculos",
general_tab:"General",
popup_tab:"Ventana emergente",
events_tab:"Eventos",
advanced_tab:"Avanzado",
general_props:"Propiedades generales",
popup_props:"Propiedades de vent. emergentes",
event_props:"Eventos",
advanced_props:"Propiedades avanzadas",
popup_opts:"Opciones",
anchor_names:"Anclas",
target_same:"Abrir en esta ventana / frame",
target_parent:"Abrir en ventana padre / frame",
target_top:"Abrir en el frame top (reemplaza todos los frames)",
target_blank:"Abrir en ventana nueva",
popup:"Javascript popup",
popup_url:"URL de la ventana emergente",
popup_name:"Nombre de la ventana",
popup_return:"Insertar 'return false'",
popup_scrollbars:"Muestra scrollbars",
popup_statusbar:"Muestra status bar",
popup_toolbar:"Muestra toolbars",
popup_menubar:"Muestra menu bar",
popup_location:"Muestra location bar",
popup_resizable:"Permitir cambiar el tama\u00F1o de la ventana",
popup_dependent:"Dependientes (Mozilla/Firefox only)",
popup_size:"Tama\u00F1o",
popup_position:"Posicion (X/Y)",
id:"Id",
style:"Estilo",
classes:"Clases",
target_name:"Nombre del Target",
langdir:"Direccion del lenguaje",
target_langcode:"Lenguaje del Target",
langcode:"Codigo del lenguaje",
encoding:"Codificacion de caracteres del Target",
mime:"Tipo MIME del Target",
rel:"Relacion pagina a target",
rev:"Relacion target a pagina",
tabindex:"Indice de tabulacion",
accesskey:"Tecla de acceso",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
link_list:"Lista de vinculo"
});