tinyMCE.addI18n('da.style_dlg',{
title:"Rediger CSS stil",
apply:"Anvend",
text_tab:"Tekst",
background_tab:"Baggrund",
block_tab:"Blok",
box_tab:"Boks",
border_tab:"Kant",
list_tab:"Liste",
positioning_tab:"Positionering",
text_props:"Tekst",
text_font:"Skrifttype",
text_size:"St\u00F8rrelse",
text_weight:"V\u00E6gt",
text_style:"Stil",
text_variant:"Variant",
text_lineheight:"Linieh\u00F8jde",
text_case:"Vesaltilstand",
text_color:"Farve",
text_decoration:"Dekoration",
text_overline:"overstreget",
text_underline:"understreget",
text_striketrough:"gennemstreget",
text_blink:"blink",
text_none:"ingen",
background_color:"Baggrundsfarve",
background_image:"Baggrundsbillede",
background_repeat:"Gentag",
background_attachment:"Vedh\u00E6ftede fil",
background_hpos:"Horisontal position",
background_vpos:"Vertikal position",
block_wordspacing:"Afstand mellem ord",
block_letterspacing:"Afstand mellem bogstaver",
block_vertical_alignment:"Vertikal justering",
block_text_align:"Tekstjustering",
block_text_indent:"Tekstindrykning",
block_whitespace:"Mellemrum",
block_display:"Vis",
box_width:"Bredde",
box_height:"H\u00F8jde",
box_float:"Flydende",
box_clear:"Ryd",
padding:"Afstand til indhold",
same:"Ens for alle",
top:"Top",
right:"H\u00F8jre",
bottom:"Bund",
left:"Venstre",
margin:"Margin",
style:"Style",
width:"Bredde",
height:"H\u00F8jde",
color:"Farve",
list_type:"Type",
bullet_image:"Punktopstillings billede",
position:"Position",
positioning_type:"Type",
visibility:"Synlighed",
zindex:"Z-index",
overflow:"Overl\u00F8b",
placement:"Placering",
clip:"Klip"
});