tinyMCE.addI18n({he:{
common:{
edit_confirm:"Do you want to use the WYSIWYG mode for this textarea?",
apply:"\u05D0\u05D9\u05E9\u05D5\u05E8",
insert:"\u05D4\u05D5\u05E1\u05E3",
update:"\u05E2\u05D3\u05DB\u05DF",
cancel:"\u05D1\u05D9\u05D8\u05D5\u05DC",
close:"\u05E1\u05D2\u05D5\u05E8",
browse:"\u05E2\u05D9\u05D9\u05DF",
class_name:"\u05DE\u05D7\u05DC\u05E7\u05D4",
not_set:"-- \u05DC\u05D0 \u05D4\u05D5\u05D2\u05D3\u05E8 --",
clipboard_msg:"\r\n        \u05D4\u05E2\u05EA\u05E7\\u05D2\u05D6\u05D5\u05E8\\u05D4\u05D3\u05D1\u05E7 \u05DC\u05D0 \u05D6\u05DE\u05D9\u05E0\u05D9\u05DD \u05D1 Mozilla \u05D5\u05D1-Firefox.\r\n        \u05D4\u05D0\u05DD \u05D1\u05E8\u05E6\u05D5\u05E0\u05DA \u05DC\u05E7\u05D1\u05DC \u05DE\u05D9\u05D3\u05E2 \u05E0\u05D5\u05E1\u05E3 \u05E2\u05DC \u05D4\u05E0\u05D5\u05E9\u05D0?\r\n      ",
clipboard_no_support:"\u05DB\u05E8\u05D2\u05E2 \u05DC\u05D0 \u05E0\u05EA\u05DE\u05DA \u05E2\u05DC \u05D9\u05D3\u05D9 \u05D4\u05D3\u05E4\u05D3\u05E4\u05DF \u05E9\u05DC\u05DA. \u05D4\u05E9\u05EA\u05DE\u05E9 \u05D1\u05E7\u05D9\u05E6\u05D5\u05E8\u05D9 \u05D4\u05DE\u05E7\u05DC\u05D3\u05EA.",
popup_blocked:"Sorry, but we have noticed that your popup-blocker has disabled a window that provides application functionality. You will need to disable popup blocking on this site in order to fully utilize this tool.",
invalid_data:"Error: Invalid values entered, these are marked in red.",
more_colors:"\u05E2\u05D5\u05D3 \u05E6\u05D1\u05E2\u05D9\u05DD"
},
contextmenu:{
align:"\u05D9\u05E9\u05E8",
left:"\u05E9\u05DE\u05D0\u05DC",
center:"\u05D0\u05DE\u05E6\u05E2",
right:"\u05D9\u05DE\u05D9\u05DF",
full:"\u05E9\u05E0\u05D9 \u05D4\u05E6\u05D3\u05D3\u05D9\u05DD"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"\u05D4\u05D5\u05E1\u05E3 \u05EA\u05D0\u05E8\u05D9\u05DA",
inserttime_desc:"\u05D4\u05D5\u05E1\u05E3 \u05D6\u05DE\u05DF",
months_long:"\u05D9\u05E0\u05D5\u05D0\u05E8,\u05E4\u05D1\u05E8\u05D5\u05D0\u05E8,\u05DE\u05E8\u05E5,\u05D0\u05E4\u05E8\u05D9\u05DC,\u05DE\u05D0\u05D9,\u05D9\u05D5\u05E0\u05E2,\u05D9\u05D5\u05DC\u05D9,\u05D0\u05D5\u05D2\u05D5\u05E1\u05D8,\u05E1\u05E4\u05D8\u05DE\u05D1\u05E8,\u05D0\u05D5\u05E7\u05D8\u05D5\u05D1\u05E8,\u05E0\u05D5\u05D1\u05DE\u05D1\u05E8,\u05D3\u05E6\u05DE\u05D1\u05E8",
months_short:"\u05D9\u05E0\u05D5\u05D0\u05E8,\u05E4\u05D1\u05E8\u05D5\u05D0\u05E8,\u05DE\u05E8\u05E5,\u05D0\u05E4\u05E8\u05D9\u05DC,\u05DE\u05D0\u05D9,\u05D9\u05D5\u05E0\u05E2,\u05D9\u05D5\u05DC\u05D9,\u05D0\u05D5\u05D2\u05D5\u05E1\u05D8,\u05E1\u05E4\u05D8\u05DE\u05D1\u05E8,\u05D0\u05D5\u05E7\u05D8\u05D5\u05D1\u05E8,\u05E0\u05D5\u05D1\u05DE\u05D1\u05E8,\u05D3\u05E6\u05DE\u05D1\u05E8",
day_long:"\u05D9\u05D5\u05DD \u05E8\u05D0\u05E9\u05D5\u05DF,\u05D9\u05D5\u05DD \u05E9\u05E0\u05D9,\u05D9\u05D5\u05DD \u05E9\u05DC\u05D9\u05E9\u05D9,\u05D9\u05D5\u05DD \u05E8\u05D1\u05D9\u05E2\u05D9,\u05D9\u05D5\u05DD \u05D7\u05DE\u05D9\u05E9\u05D9,\u05D9\u05D5\u05DD \u05E9\u05D9\u05E9,\u05D9\u05D5\u05DD \u05E9\u05D1\u05EA,\u05D9\u05D5\u05DD \u05E8\u05D0\u05E9\u05D5\u05DF",
day_short:"\u05D9\u05D5\u05DD \u05D0',\u05D9\u05D5\u05DD \u05D1',\u05D9\u05D5\u05DD \u05D2',\u05D9\u05D5\u05DD \u05D3',\u05D9\u05D5\u05DD \u05D4',\u05D9\u05D5\u05DD \u05D5',\u05E9\u05D1\u05EA,\u05D9\u05D5\u05DD \u05D0'"
},
print:{
print_desc:"\u05D4\u05D3\u05E4\u05E1"
},
preview:{
preview_desc:"\u05EA\u05E6\u05D5\u05D2\u05D4 \u05DE\u05E7\u05D3\u05D9\u05DE\u05D4"
},
directionality:{
ltr_desc:"\u05DB\u05D9\u05D5\u05D5\u05DF \u05D8\u05E7\u05E1\u05D8 \u05DE\u05E9\u05DE\u05D0\u05DC \u05DC\u05D9\u05DE\u05D9\u05DF",
rtl_desc:"\u05DB\u05D9\u05D5\u05D5\u05DF \u05D8\u05E7\u05E1\u05D8 \u05DE\u05D9\u05DE\u05D9\u05DF \u05DC\u05E9\u05DE\u05D0\u05DC"
},
layer:{
insertlayer_desc:"\u05D4\u05D5\u05E1\u05E3 \u05E9\u05DB\u05D1\u05D4 \u05D7\u05D3\u05E9\u05D4",
forward_desc:"\u05D4\u05E2\u05D1\u05E8 \u05E7\u05D3\u05D9\u05DE\u05D4",
backward_desc:"\u05D4\u05E2\u05D1\u05E8 \u05D0\u05D7\u05D5\u05E8\u05D4",
absolute_desc:"Toggle absolute positioning",
content:"\u05E9\u05DB\u05D1\u05D4 \u05D7\u05D3\u05E9\u05D4..."
},
save:{
save_desc:"\u05E9\u05DE\u05D5\u05E8",
cancel_desc:"\u05D1\u05D8\u05DC \u05D0\u05EA \u05DB\u05DC \u05D4\u05E9\u05D9\u05E0\u05D5\u05D9\u05DD"
},
nonbreaking:{
nonbreaking_desc:"\u05D4\u05D5\u05E1\u05E3 \u05E8\u05D5\u05D5\u05D7"
},
iespell:{
iespell_desc:"\u05D1\u05D3\u05D9\u05E7\u05EA \u05D0\u05D9\u05D5\u05EA",
download:" \u05DC\u05D0 \u05E0\u05DE\u05E6\u05D0 ieSpell. \u05D4\u05D0\u05DD \u05D1\u05E8\u05E6\u05D5\u05E0\u05DA \u05DC\u05D4\u05EA\u05E7\u05D9\u05DF?"
},
advhr:{
advhr_desc:"\u05E7\u05D5 \u05D0\u05D5\u05E4\u05E7\u05D9"
},
emotions:{
emotions_desc:"\u05E1\u05DE\u05D9\u05D9\u05DC\u05D9\u05DD"
},
searchreplace:{
search_desc:"\u05D7\u05D9\u05E4\u05D5\u05E9",
replace_desc:"\u05D4\u05D7\u05DC\u05E4\u05D4"
},
advimage:{
image_desc:"\u05D4\u05D5\u05E1\u05E3\\u05E2\u05E8\u05DA \u05EA\u05DE\u05D5\u05E0\u05D4"
},
advlink:{
link_desc:"\u05D4\u05D5\u05E1\u05E3\\u05E2\u05E8\u05DA \u05D4\u05D9\u05E4\u05E8-\u05E7\u05D9\u05E9\u05D5\u05E8"
},
xhtmlxtras:{
cite_desc:"Citation",
abbr_desc:"Abbreviation",
acronym_desc:"Acronym",
del_desc:"Deletion",
ins_desc:"Insertion",
attribs_desc:"Insert/Edit Attributes"
},
style:{
desc:"Edit CSS Style"
},
paste:{
paste_text_desc:"Paste as Plain Text",
paste_word_desc:"Paste from Word",
selectall_desc:"Select All"
},
paste_dlg:{
text_title:"Use CTRL+V on your keyboard to paste the text into the window.",
text_linebreaks:"Keep linebreaks",
word_title:"Use CTRL+V on your keyboard to paste the text into the window."
},
table:{
desc:"Inserts a new table",
row_before_desc:"Insert row before",
row_after_desc:"Insert row after",
delete_row_desc:"Delete row",
col_before_desc:"Insert column before",
col_after_desc:"Insert column after",
delete_col_desc:"Remove column",
split_cells_desc:"Split merged table cells",
merge_cells_desc:"Merge table cells",
row_desc:"Table row properties",
cell_desc:"Table cell properties",
props_desc:"Table properties",
paste_row_before_desc:"Paste table row before",
paste_row_after_desc:"Paste table row after",
cut_row_desc:"Cut table row",
copy_row_desc:"Copy table row",
del:"Delete table",
row:"Row",
col:"Column",
cell:"Cell"
},
autosave:{
unload_msg:"The changes you made will be lost if you navigate away from this page."
},
fullscreen:{
desc:"Toggle fullscreen mode"
},
media:{
desc:"Insert / edit embedded media",
edit:"Edit embedded media"
},
fullpage:{
desc:"Document properties"
},
template:{
desc:"Insert predefined template content"
},
visualchars:{
desc:"Visual control characters on/off."
},
spellchecker:{
desc:"Toggle spellchecker",
menu:"Spellchecker settings",
ignore_word:"Ignore word",
ignore_words:"Ignore all",
langs:"\u05E9\u05E4\u05D5\u05EA",
wait:"Please wait...",
sug:"Suggestions",
no_sug:"No suggestions",
no_mpell:"No misspellings found."
},
pagebreak:{
desc:"Insert page break."
}}});