tinyMCE.addI18n('he.advanced_dlg',{
about_title:"\u05D0\u05D5\u05D3\u05D5\u05EA TinyMCE",
about_general:"\u05D0\u05D5\u05D3\u05D5\u05EA",
about_help:"\u05D0\u05D6\u05E8\u05E2",
about_license:"\u05E8\u05E9\u05D9\u05D5\u05DF",
about_plugins:"\u05EA\u05D5\u05E1\u05E4\u05D5\u05EA",
about_plugin:"\u05EA\u05D5\u05E1\u05E4\u05EA",
about_author:"\u05D9\u05D5\u05E6\u05E8",
about_version:"\u05D2\u05D9\u05E8\u05E1\u05D4",
about_loaded:"\u05EA\u05D5\u05E1\u05E4\u05D5\u05EA \u05E4\u05E2\u05D9\u05DC\u05D5\u05EA",
anchor_title:"\u05D4\u05D5\u05E1\u05E3\\u05E2\u05E8\u05DA \u05E1\u05D9\u05DE\u05E0\u05D9\u05D4",
anchor_name:"\u05E9\u05DD \u05D4\u05E1\u05D9\u05DE\u05E0\u05D9\u05D4",
code_title:"\u05E2\u05D5\u05E8\u05DA \u05D4-HTML",
code_wordwrap:"\u05D4\u05E2\u05D1\u05E8\u05EA \u05DE\u05D9\u05DC\u05D9\u05DD",
colorpicker_title:"\u05D1\u05D7\u05E8 \u05E6\u05D1\u05E2",
colorpicker_picker_tab:"\u05D1\u05D5\u05E8\u05E8",
colorpicker_picker_title:"\u05D1\u05D5\u05E8\u05E8 \u05D4\u05E6\u05D1\u05E2\u05D9\u05DD",
colorpicker_palette_tab:"\u05DC\u05D5\u05D7 \u05E6\u05D1\u05E2\u05D9\u05DD",
colorpicker_palette_title:"\u05DC\u05D5\u05D7 \u05E6\u05D1\u05E2\u05D9\u05DD",
colorpicker_named_tab:"\u05DB\u05E0\u05D5\u05D9",
colorpicker_named_title:"\u05E6\u05D1\u05E2\u05D9\u05DD \u05DB\u05E0\u05D5\u05D9\u05DD",
colorpicker_color:"\u05E6\u05D1\u05E2:",
colorpicker_name:"\u05E9\u05DD:",
charmap_title:"\u05D1\u05D7\u05E8 \u05E1\u05D9\u05DE\u05DF",
image_title:"\u05D4\u05D5\u05E1\u05E3\\u05E2\u05E8\u05DA \u05EA\u05DE\u05D5\u05E0\u05D4",
image_src:"\u05DB\u05EA\u05D5\u05D1\u05EA:",
image_alt:"\u05EA\u05D9\u05D0\u05D5\u05E8",
image_list:"\u05E8\u05E9\u05D9\u05DE\u05D4",
image_border:"\u05D2\u05D1\u05D5\u05DC",
image_dimensions:"\u05D2\u05D5\u05D3\u05DC",
image_vspace:"\u05E8\u05D5\u05D5\u05D7 \u05D0\u05E0\u05DB\u05D9",
image_hspace:"\u05E8\u05D5\u05D5\u05D7 \u05D0\u05D5\u05E4\u05E7\u05D9",
image_align:"\u05D9\u05E9\u05E8",
image_align_baseline:"\u05E7\u05D5 \u05D4\u05D4\u05EA\u05D7\u05DC\u05D4",
image_align_top:"\u05E7\u05E6\u05D4 \u05D4\u05E2\u05DC\u05D9\u05D5\u05DF",
image_align_middle:"\u05D0\u05DE\u05E6\u05E2",
image_align_bottom:"\u05E7\u05E6\u05D4 \u05D4\u05EA\u05D7\u05EA\u05D5\u05DF",
image_align_texttop:"\u05E7\u05E6\u05D4 \u05D4\u05E2\u05DC\u05D9\u05D5\u05DF \u05E9\u05DC \u05D4\u05D8\u05E7\u05E1\u05D8",
image_align_textbottom:"\u05E7\u05E6\u05D4 \u05D4\u05EA\u05D7\u05EA\u05D5\u05DF \u05E9\u05DC \u05D4\u05D8\u05E7\u05E1\u05D8",
image_align_left:"\u05E9\u05DE\u05D0\u05DC",
image_align_right:"\u05D9\u05DE\u05D9\u05DF",
link_title:"\u05D4\u05D5\u05E1\u05E3\\u05E2\u05E8\u05DA link",
link_url:"\u05DB\u05EA\u05D5\u05D1\u05EA \u05D4\u05D4\u05D9\u05E4\u05E8-\u05E7\u05D9\u05E9\u05D5\u05E8",
link_target:"\u05D9\u05E2\u05D3",
link_target_same:"Open link in the same window",
link_target_blank:"Open link in a new window",
link_titlefield:"\u05DB\u05D5\u05EA\u05E8\u05EA",
link_is_email:"The URL you entered seems to be an email address, do you want to add the required mailto: prefix?",
link_is_external:"The URL you entered seems to external link, do you want to add the required http:// prefix?",
link_list:"Link list"
});