tinyMCE.addI18n('zh.advanced_dlg',{
about_title:" \u95DC\u65BC TinyMCE",
about_general:" \u95DC\u65BC ",
about_help:" \u5E6B\u52A9 ",
about_license:" \u6388\u6B0A ",
about_plugins:" \u6240\u6709\u5916\u639B\u7A0B\u5E8F ",
about_plugin:" \u5916\u639B\u7A0B\u5E8F ",
about_author:" \u4F5C\u8005 ",
about_version:" \u7248\u672C ",
about_loaded:" \u5DF2\u52A0\u8F09\u5916\u639B\u7A0B\u5E8F ",
anchor_title:" \u63D2\u5165 / \u7DE8\u8F2F \u9328\u9EDE ",
anchor_name:" \u9328\u9EDE\u540D\u7A31 ",
code_title:" \u539F\u59CB\u7A0B\u5E8F\u4EE3\u78BC\u7DE8\u8F2F\u5668 ",
code_wordwrap:" \u81EA\u52D5\u63DB\u884C ",
colorpicker_title:" \u9078\u64C7\u984F\u8272 ",
colorpicker_picker_tab:" \u53D6\u8272\u677F ",
colorpicker_picker_title:" \u53D6\u8272\u677F\u984F\u8272 ",
colorpicker_palette_tab:" \u8ABF\u8272\u677F ",
colorpicker_palette_title:" \u8ABF\u8272\u677F\u984F\u8272 ",
colorpicker_named_tab:" \u547D\u540D\u8272 ",
colorpicker_named_title:" \u547D\u540D\u8272\u984F\u8272 ",
colorpicker_color:" \u984F\u8272 :",
colorpicker_name:" \u540D\u7A31 :",
charmap_title:" \u63D2\u5165\u7279\u6B8A\u7B26\u865F ",
image_title:" \u63D2\u5165 / \u7DE8\u8F2F \u5716\u7247 ",
image_src:" \u5716\u7247\u5730\u5740 ",
image_alt:" \u5716\u7247\u63CF\u8FF0 ",
image_list:" \u5716\u7247\u6E05\u55AE ",
image_border:" \u908A\u6846 ",
image_dimensions:" \u5C3A\u5BF8 ",
image_vspace:" \u5782\u76F4\u9593\u8DDD ",
image_hspace:" \u6C34\u5E73\u9593\u8DDD ",
image_align:" \u5C0D\u9F4A\u65B9\u5F0F ",
image_align_baseline:" \u57FA\u7DDA ",
image_align_top:" \u9802\u7AEF\u5C0D\u9F4A ",
image_align_middle:" \u7F6E\u4E2D ",
image_align_bottom:" \u5E95\u7AEF\u5C0D\u9F4A ",
image_align_texttop:" \u6587\u672C\u4E0A\u65B9 ",
image_align_textbottom:" \u6587\u672C\u4E0B\u65B9 ",
image_align_left:" \u9760\u5DE6\u5C0D\u9F4A ",
image_align_right:" \u9760\u53F3\u5C0D\u9F4A ",
link_title:" \u63D2\u5165 / \u7DE8\u8F2F \u9023\u7D50 ",
link_url:" \u9023\u7D50\u5730\u5740 ",
link_target:" \u76EE\u6A19 ",
link_target_same:" \u7576\u524D\u7A97\u53E3 ",
link_target_blank:" \u6253\u958B\u65B0\u7A97\u53E3 ",
link_titlefield:"Title \u5C6C\u6027 ",
link_is_email:" \u662F\u5426\u70BA\u8A72\u96FB\u5B50\u90F5\u5BC4\u5730\u5740\u6DFB\u52A0\u6240\u9700\u7684 mailto: \u524D\u7DB4 ?",
link_is_external:" \u662F\u5426\u70BA\u5916\u90E8\u9023\u7D50\u6DFB\u52A0\u6240\u9700\u7684 http:// \u524D\u7DB4 ?",
link_list:" \u9023\u7D50\u6E05\u55AE "
});