tinyMCE.addI18n('he.advimage_dlg',{
tab_general:"\u05DB\u05DC\u05DC\u05D9",
tab_appearance:"Appearance",
tab_advanced:"Advanced",
general:"\u05DB\u05DC\u05DC\u05D9",
title:"\u05DB\u05D5\u05EA\u05E8\u05EA",
preview:"Preview",
constrain_proportions:"Constrain proportions",
langdir:"\u05DB\u05D9\u05D5\u05D5\u05DF \u05D4\u05E9\u05E4\u05D4",
langcode:"\u05E7\u05D5\u05D3 \u05D4\u05E9\u05E4\u05D4",
long_desc:"Long description link",
style:"Style",
classes:"Classes",
ltr:"\u05DE\u05E9\u05DE\u05D0\u05DC \u05DC\u05D9\u05DE\u05D9\u05DF",
rtl:"\u05DE\u05D9\u05DE\u05D9\u05DF \u05DC\u05E9\u05DE\u05D0\u05DC",
id:"Id",
map:"Image map",
swap_image:"Swap image",
alt_image:"Alternative image",
mouseover:"for mouse over",
mouseout:"for mouse out",
misc:"Miscellaneous",
example_img:"Appearance preview image",
missing_alt:"Are you sure you want to continue without including an Image Description? Without it the image may not be accessible to some users with disabilities, or to those using a text browser, or browsing the Web with images turned off.",
dialog_title:"\u05D4\u05D5\u05E1\u05E3\\u05E2\u05E8\u05DA \u05EA\u05DE\u05D5\u05E0\u05D4",
src:"Image URL",
alt:"Image description",
list:"Image list",
border:"Border",
dimensions:"Dimensions",
vspace:"Vertical space",
hspace:"Horizontal space",
align:"\u05D9\u05E9\u05D5\u05E8",
align_baseline:"Baseline",
align_top:"Top",
align_middle:"Middle",
align_bottom:"Bottom",
align_texttop:"Text top",
align_textbottom:"Text bottom",
align_left:"\u05DC\u05E9\u05DE\u05D0\u05DC",
align_right:"Right",
image_list:"Image list"
});