tinyMCE.addI18n('cs.style_dlg',{
title:"Upravit CSS styl",
apply:"Pou\u017E\u00EDt",
text_tab:"Text",
background_tab:"Pozad\u00ED",
block_tab:"Blok",
box_tab:"Box",
border_tab:"Okraj",
list_tab:"Seznam",
positioning_tab:"Um\u00EDst\u011Bn\u00ED",
text_props:"Text",
text_font:"Font",
text_size:"Velikost",
text_weight:"\u0160\u00ED\u0159ka",
text_style:"Styl",
text_variant:"Varianta",
text_lineheight:"Tlou\u0161\u0165ka \u010D\u00E1ry",
text_case:"P\u0159\u00EDpad",
text_color:"Barva",
text_decoration:"Dekorace",
text_overline:"nadtr\u017Een\u00ED",
text_underline:"podtr\u017Een\u00ED",
text_striketrough:"p\u0159e\u0161krtnut\u00ED",
text_blink:"blik\u00E1n\u00ED",
text_none:"z\u00E1dn\u00E9",
background_color:"Barva pozad\u00ED",
background_image:"Obr\u00E1zek pozad\u00ED",
background_repeat:"Opakov\u00E1n\u00ED",
background_attachment:"p\u0159\u00EDloha",
background_hpos:"Horizont\u00E1ln\u00ED um\u00EDst\u011Bn\u00ED",
background_vpos:"Vertik\u00E1ln\u00ED um\u00EDst\u011Bn\u00ED",
block_wordspacing:"Rozestup slov",
block_letterspacing:"Rozestup znaku",
block_vertical_alignment:"Vertik\u00E1ln\u00ED zarovn\u00E1n\u00ED",
block_text_align:"Zarovn\u00E1n\u00ED textu",
block_text_indent:"Odsazen\u00ED textu",
block_whitespace:"Pr\u00E1zdn\u00E9 m\u00EDsto",
block_display:"Zobrazen\u00ED",
box_width:"\u0160\u00ED\u0159ka",
box_height:"V\u00FD\u0161ka",
box_float:"Plav\u00E1n\u00ED",
box_clear:"Vy\u010Distit",
padding:"Padding",
same:"Stejn\u00E9 pro v\u0161echny",
top:"Nahoru",
right:"Vpravo",
bottom:"Dol\u016F",
left:"Vlevo",
margin:"Okraj",
style:"Styl",
width:"\u0160\u00ED\u0159ka",
height:"V\u00FD\u0161ka",
color:"Barva",
list_type:"Typ",
bullet_image:"Bullet image",
position:"Pozice",
positioning_type:"Typ",
visibility:"Viditelnost",
zindex:"Z-index",
overflow:"Overflow",
placement:"Um\u00EDstn\u011Bni",
clip:"Klip"
});