tinyMCE.addI18n('nb.simple',{
bold_desc:"Fet (Ctrl+B)",
italic_desc:"Kursiv (Ctrl+I)",
underline_desc:"Understreket (Ctrl+U)",
striketrough_desc:"Gjennomstreket",
bullist_desc:"Punktliste",
numlist_desc:"Nummerliste",
undo_desc:"Angre (Ctrl+Z)",
redo_desc:"Gj\u00F8r om (Ctrl+Y)",
cleanup_desc:"Rens uryddig kode"
});