tinyMCE.addI18n('es.advimage_dlg',{
tab_general:"General",
tab_appearance:"Apariencia",
tab_advanced:"Avanzado",
general:"General",
title:"Titulo",
preview:"Vista previa",
constrain_proportions:"Bloquear relacion de aspecto",
langdir:"Direccion del lenguaje",
langcode:"Codigo del lenguaje",
long_desc:"Vinculo para descripcion larga",
style:"Estilos",
classes:"Clases",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
id:"Id",
map:"Mapa de imagen",
swap_image:"Intercambiar imagen",
alt_image:"Imagen alternativa",
mouseover:"para mouse over",
mouseout:"para mouse out",
misc:"Miscellaneous",
example_img:"Vista previa de la imagen",
missing_alt:"Esta seguro que desea continuar sin una descripcion de la imagen? Sin esta puede no ser accesible para usuarios con discapacidades, o para aquellos que usen navegadores de solo texto, o navegan la pagina con las imagenes deshabilitadas.",
dialog_title:"Insertar/editar imagen",
src:"URL de la imagen",
alt:"Descripcion de la imagen",
list:"Lista de imagen",
border:"Bordes",
dimensions:"Dimensiones",
vspace:"Espacio vertical",
hspace:"Espacio horizontal",
align:"Alineacion",
align_baseline:"Baseline",
align_top:"Arriba",
align_middle:"Medio",
align_bottom:"Debajo",
align_texttop:"Texto arriba",
align_textbottom:"Texto abajo",
align_left:"Izquierda",
align_right:"Derecha",
image_list:"Lista de imagen"
});