tinyMCE.addI18n('ar.table_dlg',{
general_tab:"\u0639\u0627\u0645",
advanced_tab:"\u0645\u062A\u0642\u062F\u0645",
general_props:"\u062E\u0635\u0627\u0626\u0635 \u0639\u0627\u0645\u0629",
advanced_props:"\u062E\u0635\u0627\u0626\u0635 \u0645\u062A\u0642\u062F\u0645\u0629",
rowtype:"Row in table part",
title:"\u0625\u062F\u0631\u0627\u062C/\u062A\u0639\u062F\u064A\u0644 \u062C\u062F\u0648\u0644",
width:"\u0627\u0644\u0639\u0631\u0636",
height:"\u0627\u0644\u0625\u0631\u062A\u0641\u0627\u0639",
cols:"\u0627\u0639\u0645\u062F\u0629",
rows:"\u0635\u0641\u0648\u0641",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"\u0627\u0644\u062D\u062F\u0648\u062F",
align:"\u0645\u062D\u0627\u0630\u0627\u0629",
align_default:"Default",
align_left:"\u064A\u0633\u0627\u0631",
align_right:"\u064A\u0645\u064A\u0646",
align_middle:"Center",
row_title:"Table row \u062E\u0635\u0627\u0626\u0635",
cell_title:"Table cell \u062E\u0635\u0627\u0626\u0635",
cell_type:"Cell type",
valign:"Vertical alignment",
align_top:"\u0623\u0639\u0644\u0649",
align_bottom:"\u0623\u0633\u0641\u0644",
bordercolor:"\u0627\u0644\u062D\u062F\u0648\u062F color",
bgcolor:"\u0644\u0648\u0646 \u0627\u0644\u062E\u0644\u0641\u064A\u0629",
merge_cells_title:"Merge table cells",
id:"Id",
style:"Style",
langdir:"\u0627\u062A\u062C\u0627\u0647 \u0627\u0644\u0644\u063A\u0629",
langcode:"\u0634\u0641\u0631\u0629 \u0627\u0644\u0644\u063A\u0629",
mime:"\u0627\u0644\u0645\u0633\u0627\u0631 MIME type",
ltr:"\u064A\u0633\u0627\u0631 to \u064A\u0645\u064A\u0646",
rtl:"\u064A\u0645\u064A\u0646 to \u064A\u0633\u0627\u0631",
bgimage:"\u0635\u0648\u0631\u0629 \u0627\u0644\u062E\u0644\u0641\u064A\u0629",
summary:"Summary",
td:"Data",
th:"Header",
cell_cell:"Update current cell",
cell_row:"Update all cells in row",
cell_all:"Update all cells in table",
row_row:"Update current row",
row_odd:"Update odd rows in table",
row_even:"Update even rows in table",
row_all:"Update all rows in table",
thead:"Table Head",
tbody:"Table Body",
tfoot:"Table Foot",
scope:"Scope",
rowgroup:"Row Group",
colgroup:"Col Group",
col_limit:"You've exceeded the maximum number of columns of {$cols}.",
row_limit:"You've exceeded the maximum number of rows of {$rows}.",
cell_limit:"You've exceeded the maximum number of cells of {$cells}.",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Table caption",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});