tinyMCE.addI18n('nb.emotions_dlg',{
title:"Lim inn f\u00F8lelse",
desc:"F\u00F8lelser",
cool:"Cool",
cry:"Gr\u00E5t",
embarassed:"Sjenert",
foot_in_mouth:"Fot i munnen",
frown:"Lei seg",
innocent:"Uskyldig",
kiss:"Kyss",
laughing:"Ler",
money_mouth:"Penger i munnen",
sealed:"Hemmelig",
smile:"Smil",
surprised:"Overrasket",
tongue_out:"Rekke tunge",
undecided:"Betenkt",
wink:"Fl\u00F8rt",
yell:"Skrik"
});