tinyMCE.addI18n('pt.advlink_dlg',{
title:"Inserir/editar link",
url:"URL do Link",
target:"Alvo",
titlefield:"T\u00EDtulo",
is_email:"A URL digitada parece ser um endere\u00E7o de e-mail. Deseja acrescentar o (necess\u00E1rio) prefixo mailto:?",
is_external:"A URL digitada parece conduzir a um link externo. Deseja acrescentar o (necess\u00E1rio) prefixo http://?",
list:"Lista de Links",
general_tab:"Geral",
popup_tab:"Popup",
events_tab:"Eventos",
advanced_tab:"Avan\u00E7ado",
general_props:"Propriedades Gerais",
popup_props:"Propriedades de Popup",
event_props:"Eventos",
advanced_props:"Propriedades Avan\u00E7adas",
popup_opts:"Op\u00E7\u00F5es",
anchor_names:"\u00C2ncoras",
target_same:"Abrir nessa janela/frame",
target_parent:"Abrir na janela/frame parent",
target_top:"Abrir na top frame (substitue todas frames)",
target_blank:"Abrir em nova janela",
popup:"Popup Javascript",
popup_url:"URL do Popup",
popup_name:"Nome da Janela",
popup_return:"Inserir 'return false'",
popup_scrollbars:"Mostrar barras de rolagem",
popup_statusbar:"Mostrar barra de status",
popup_toolbar:"Mostrar barras de ferramentas",
popup_menubar:"Mostrar barra de menu",
popup_location:"Mostrar barra de endere\u00E7os",
popup_resizable:"Permitir altera\u00E7\u00E3o do tamanho da janela",
popup_dependent:"Dependente (Mozilla/Firefox apenas)",
popup_size:"Tamanho",
popup_position:"Posi\u00E7\u00E3o (X/Y)",
id:"Id",
style:"Estilo",
classes:"Classes",
target_name:"Nome do Alvo",
langdir:"Dire\u00E7\u00E3o do texto",
target_langcode:"linguagem alvo",
langcode:"C\u00F3digo da linguagem",
encoding:"Codifica\u00E7\u00E3o de caracteres",
mime:"Tipo MIME alvo",
rel:"Rela\u00E7\u00E3o p\u00E1gina/alvo",
rev:"Rela\u00E7\u00E3o alvo/p\u00E1gina",
tabindex:"Tabindex",
accesskey:"Chave de Acesso",
ltr:"Esquerda Para Direita",
rtl:"Direita Para Esquerda",
link_list:"Lista de Links"
});