tinyMCE.addI18n('hu.searchreplace_dlg',{
searchnext_desc:"Keres\u00E9s megint",
notfound:"A keres\u00E9s v\u00E9get \u00E9rt. A keresett sz\u00F6vegr\u00E9sz nem tal\u00E1lhat\u00F3.",
search_title:"Keres\u00E9s",
replace_title:"Keres\u00E9s/Csere",
allreplaced:"A keresett r\u00E9szsz\u00F6veg minden el\u0151fordul\u00E1sa cser\u00E9lve lett.",
findwhat:"Cser\u00E9lni val\u00F3",
replacewith:"Csere erre",
direction:"Ir\u00E1ny",
up:"Fel",
down:"Le",
mcase:"Kis/Nagybet\u0171 \u00E9rz\u00E9kenys\u00E9g",
findnext:"Keres\u00E9s",
replace:"Cser\u00E9l",
replaceall:"Mindet cser\u00E9l"
});